
(* lexical analyzer template (TP Lex V3.0), V1.0 3-2-91 AG *)

(* global definitions: *)

{***********************************************************}
{   This file is part of the DORB project.                  }
{                                                           }
{   See the file License, included in this distribution,    }
{   for details about the copyright.                        }
{                                                           }
{   Send comments and/or bug reports to: vic@inec.ru        }
{***********************************************************}

const
  _n = chr(10); // \n
  _t = chr(9); // \t
  _v = chr(11); // \v
  _b = chr(8); // \b
  _r = chr(13); // \r
  _f = chr(12); // \f
  _a = chr(7); // \a
  _bslash = chr(92); // \\
  _sq = chr(39); // \'
  _dq = chr(34); // \"

function ascii_to_longlong( base: integer; s: PChar) : longint;
var
  c: char;
begin
  result := 0;
  while s^ <> chr(0) do
    begin
      c := s^;
      s := PChar(integer(s)+1);
      if  c >= 'a' then
        c := chr(ord(c) - (ord('a') - ord('A')));
      c := chr(ord(c) - ord('0'));
      if ord(c) > 9 then
        c := chr(ord(c) - (ord('A') - ord('0') - 10));
      result := result * base + ord(c);
  end
end;

function translate_char( const  s: string): char;
var
  c: char;
begin
  if  s[1] <> '\' then
    begin
      result := s[1];
      exit;
    end;
  c := s[2];
  case c of
  'n': result := _n;
  't': result := _t;
  'v': result := _v;
  'b': result := _b;
  'r': result := _r;
  'f': result := _f;
  'a': result := _a;
  '\': result := _bslash;
  '''': result := _sq;
  '"': result := _dq;
  'x','X' : result := chr(ascii_to_longlong( 16, PChar(integer(PChar(s))+2)));
  else
    // Gotta be an octal
    result := chr(ascii_to_longlong( 8, PChar(s)));
  end
end;



function yylex : Integer;

procedure yyaction ( yyruleno : Integer );
  (* local definitions: *)

begin
  (* actions: *)
  case yyruleno of
  1:
       			;
  2:
    			inc(idl_line_no);
  3:
          		;
  4:
                        begin
                          yylval.yy_str := yytext;
                          inc(idl_line_no);
                          return(T_PRAGMA);
                        end;
  5:
                        begin
                          preprocessor_directive( yytext );
			  yylval.yy_str := yytext;
                          return(T_INCLUDE);
                        end;
  6:
                        ;
  7:
   			return(T_LEFT_CURLY_BRACKET);
  8:
   			return(T_RIGHT_CURLY_BRACKET);
  9:
   		 	return(T_LEFT_SQUARE_BRACKET);
  10:
   			return(T_RIGHT_SQUARE_BRACKET);
  11:
   			return(T_LEFT_PARANTHESIS);
  12:
   			return(T_RIGHT_PARANTHESIS);
  13:
   			return(T_COLON);
  14:
   			return(T_COMMA);
  15:
   			return(T_SEMICOLON);
  16:
   			return(T_EQUAL);
  17:
    			return(T_SHIFTRIGHT);
  18:
    			return(T_SHIFTLEFT);
  19:
   			return(T_PLUS_SIGN);
  20:
   			return(T_MINUS_SIGN);
  21:
   			return(T_ASTERISK);
  22:
   			return(T_SOLIDUS);
  23:
   			return(T_PERCENT_SIGN);
  24:
   			return(T_TILDE);
  25:
   			return(T_VERTICAL_LINE);
  26:
   			return(T_CIRCUMFLEX);
  27:
   			return(T_AMPERSAND);
  28:
   			return(T_LESS_THAN_SIGN);
  29:
   			return(T_GREATER_THAN_SIGN);

  30:
     			return(T_CONST);
  31:
       			return(T_TYPEDEF);
  32:
     			return(T_FLOAT);
  33:
      			return(T_DOUBLE);
  34:
    			return(T_CHAR);
  35:
     			return(T_WCHAR);
  36:
                        return(T_FIXED);
  37:
       			return(T_BOOLEAN);
  38:
      			return(T_STRING);
  39:
       			return(T_WSTRING);
  40:
    			return(T_VOID);
  41:
        		return(T_UNSIGNED);
  42:
     			return(T_LONG);
  43:
     			return(T_SHORT);
  44:
     			return(T_FALSE);
  45:
    			return(T_TRUE);
  46:
      			return(T_STRUCT);
  47:
     			return(T_UNION);
  48:
      			return(T_SWITCH);
  49:
    			return(T_CASE);
  50:
       			return(T_DEFAULT);
  51:
    			return(T_ENUM);
  52:
  			return(T_IN);
  53:
   			return(T_OUT);
  54:
         		return(T_INTERFACE);
  55:
        		return(T_ABSTRACT);
  56:
         		return(T_VALUETYPE);
  57:
           		return(T_TRUNCATABLE);
  58:
        		return(T_SUPPORTS);
  59:
      			return(T_CUSTOM);
  60:
      			return(T_PUBLIC);
  61:
       			return(T_PRIVATE);
  62:
       			return(T_FACTORY);
  63:
      			return(T_NATIVE);
  64:
         		return(T_VALUEBASE);
  65:
    			return(T_SCOPE);
  66:
      			return(T_MODULE);
  67:
     			return(T_OCTET);
  68:
   			return(T_ANY);
  69:
        		return(T_SEQUENCE);
  70:
        		return(T_READONLY);
  71:
         		return(T_ATTRIBUTE);
  72:
         		return(T_EXCEPTION);
  73:
      			return(T_ONEWAY);
  74:
     			return(T_INOUT);
  75:
      			return(T_RAISES);
  76:
       			return(T_CONTEXT);
  77:
                        return(T_OBJECT);
  78:
                  	begin
                          if yytext[1] = '_' then
			    yylval.yyident := copy(yytext,2,100)
			  else
			    yylval.yyident := yytext;
			  return(T_IDENTIFIER);
                        end;
  79,
  80,
  81,
  82,
  83,
  84:
                	begin
                          if (DecimalSeparator <> '.') and (pos('.',yytext) > 0) then
                            yytext[pos('.',yytext)] := DecimalSeparator
                          else if (DecimalSeparator <> ',') and (pos(',',yytext) > 0) then
                            yytext[pos(',',yytext)] := DecimalSeparator;
                          yylval.yy_float := strtofloat(yytext);
			  return(T_FLOATING_PT_LITERAL);
                        end;
  85,
  86,
  87,
  88:
                	begin
                          if (DecimalSeparator <> '.') and (pos('.',yytext) > 0) then
                            yytext[pos('.',yytext)] := DecimalSeparator
                          else if (DecimalSeparator <> ',') and (pos(',',yytext) > 0) then
                            yytext[pos(',',yytext)] := DecimalSeparator;
                          yylval.yy_float := strtofloat(yytext);
			  return(T_FLOATING_PT_LITERAL);
                        end;
  89:
             		begin
                          yylval.yy_int := strtoint(yytext );
			  return(T_INTEGER_LITERAL);
                        end;
  90:
             		begin
                          yylval.yy_int := ascii_to_longlong(8,PChar(AnsiString(yytext)));
			  return(T_INTEGER_LITERAL);
                        end;
  91:
             		begin
                          yylval.yy_int := strtoint(yytext);
			  return(T_INTEGER_LITERAL);
                        end;
  92:
              		begin
                          yytext := copy(yytext,2,length(yytext)-2);
                          if yytext[1] = '\' then
                            yylval.yy_char := translate_char(yytext)
                          else
                            yylval.yy_char := yytext[1];
			  return(T_CHARACTER_LITERAL);
                        end;
  93:
                	begin
                          yylval.yy_str := copy(yytext,2,length(yytext)-2);
			  return(T_STRING_LITERAL);
                        end;
  94:
                        return(T_UNKNOWN);

  end;
end(*yyaction*);

(* DFA table: *)

type YYTRec = record
                cc : set of Char;
                s  : Integer;
              end;

const

yynmarks   = 408;
yynmatches = 408;
yyntrans   = 742;
yynstates  = 360;

yyk : array [1..yynmarks] of Integer = (
  { 0: }
  { 1: }
  { 2: }
  1,
  94,
  { 3: }
  2,
  { 4: }
  22,
  94,
  { 5: }
  94,
  { 6: }
  7,
  94,
  { 7: }
  8,
  94,
  { 8: }
  9,
  94,
  { 9: }
  10,
  94,
  { 10: }
  11,
  94,
  { 11: }
  12,
  94,
  { 12: }
  13,
  94,
  { 13: }
  14,
  94,
  { 14: }
  15,
  94,
  { 15: }
  16,
  94,
  { 16: }
  29,
  94,
  { 17: }
  28,
  94,
  { 18: }
  19,
  94,
  { 19: }
  20,
  94,
  { 20: }
  21,
  94,
  { 21: }
  23,
  94,
  { 22: }
  24,
  94,
  { 23: }
  25,
  94,
  { 24: }
  26,
  94,
  { 25: }
  27,
  94,
  { 26: }
  78,
  94,
  { 27: }
  78,
  94,
  { 28: }
  78,
  94,
  { 29: }
  78,
  94,
  { 30: }
  78,
  94,
  { 31: }
  78,
  94,
  { 32: }
  78,
  94,
  { 33: }
  78,
  94,
  { 34: }
  78,
  94,
  { 35: }
  78,
  94,
  { 36: }
  78,
  94,
  { 37: }
  78,
  94,
  { 38: }
  78,
  94,
  { 39: }
  78,
  94,
  { 40: }
  78,
  94,
  { 41: }
  78,
  94,
  { 42: }
  78,
  94,
  { 43: }
  78,
  94,
  { 44: }
  78,
  94,
  { 45: }
  78,
  94,
  { 46: }
  78,
  94,
  { 47: }
  78,
  94,
  { 48: }
  78,
  94,
  { 49: }
  90,
  94,
  { 50: }
  94,
  { 51: }
  89,
  94,
  { 52: }
  94,
  { 53: }
  94,
  { 54: }
  94,
  { 55: }
  94,
  { 56: }
  3,
  { 57: }
  { 58: }
  65,
  { 59: }
  17,
  { 60: }
  18,
  { 61: }
  78,
  { 62: }
  78,
  { 63: }
  78,
  { 64: }
  78,
  { 65: }
  78,
  { 66: }
  78,
  { 67: }
  78,
  { 68: }
  78,
  { 69: }
  78,
  { 70: }
  78,
  { 71: }
  78,
  { 72: }
  78,
  { 73: }
  78,
  { 74: }
  78,
  { 75: }
  78,
  { 76: }
  78,
  { 77: }
  78,
  { 78: }
  78,
  { 79: }
  78,
  { 80: }
  78,
  { 81: }
  78,
  { 82: }
  78,
  { 83: }
  78,
  { 84: }
  78,
  { 85: }
  78,
  { 86: }
  78,
  { 87: }
  78,
  { 88: }
  78,
  { 89: }
  52,
  78,
  { 90: }
  78,
  { 91: }
  78,
  { 92: }
  78,
  { 93: }
  78,
  { 94: }
  78,
  { 95: }
  78,
  { 96: }
  78,
  { 97: }
  78,
  { 98: }
  78,
  { 99: }
  78,
  { 100: }
  78,
  { 101: }
  78,
  { 102: }
  78,
  { 103: }
  78,
  { 104: }
  { 105: }
  82,
  { 106: }
  { 107: }
  85,
  { 108: }
  90,
  { 109: }
  91,
  { 110: }
  83,
  { 111: }
  89,
  { 112: }
  { 113: }
  { 114: }
  { 115: }
  { 116: }
  93,
  { 117: }
  { 118: }
  { 119: }
  { 120: }
  6,
  { 121: }
  { 122: }
  78,
  { 123: }
  78,
  { 124: }
  78,
  { 125: }
  78,
  { 126: }
  78,
  { 127: }
  78,
  { 128: }
  78,
  { 129: }
  78,
  { 130: }
  78,
  { 131: }
  78,
  { 132: }
  78,
  { 133: }
  78,
  { 134: }
  78,
  { 135: }
  78,
  { 136: }
  78,
  { 137: }
  78,
  { 138: }
  78,
  { 139: }
  78,
  { 140: }
  78,
  { 141: }
  78,
  { 142: }
  78,
  { 143: }
  78,
  { 144: }
  78,
  { 145: }
  78,
  { 146: }
  78,
  { 147: }
  78,
  { 148: }
  78,
  { 149: }
  78,
  { 150: }
  78,
  { 151: }
  78,
  { 152: }
  53,
  78,
  { 153: }
  78,
  { 154: }
  78,
  { 155: }
  78,
  { 156: }
  68,
  78,
  { 157: }
  78,
  { 158: }
  78,
  { 159: }
  78,
  { 160: }
  78,
  { 161: }
  78,
  { 162: }
  78,
  { 163: }
  78,
  { 164: }
  78,
  { 165: }
  78,
  { 166: }
  81,
  { 167: }
  { 168: }
  86,
  { 169: }
  { 170: }
  80,
  { 171: }
  { 172: }
  87,
  { 173: }
  92,
  { 174: }
  { 175: }
  { 176: }
  { 177: }
  { 178: }
  { 179: }
  { 180: }
  { 181: }
  78,
  { 182: }
  78,
  { 183: }
  34,
  78,
  { 184: }
  49,
  78,
  { 185: }
  78,
  { 186: }
  78,
  { 187: }
  78,
  { 188: }
  78,
  { 189: }
  78,
  { 190: }
  78,
  { 191: }
  78,
  { 192: }
  78,
  { 193: }
  78,
  { 194: }
  78,
  { 195: }
  78,
  { 196: }
  78,
  { 197: }
  78,
  { 198: }
  78,
  { 199: }
  78,
  { 200: }
  78,
  { 201: }
  78,
  { 202: }
  40,
  78,
  { 203: }
  78,
  { 204: }
  78,
  { 205: }
  78,
  { 206: }
  42,
  78,
  { 207: }
  78,
  { 208: }
  45,
  78,
  { 209: }
  51,
  78,
  { 210: }
  78,
  { 211: }
  78,
  { 212: }
  78,
  { 213: }
  78,
  { 214: }
  78,
  { 215: }
  78,
  { 216: }
  78,
  { 217: }
  78,
  { 218: }
  78,
  { 219: }
  78,
  { 220: }
  78,
  { 221: }
  78,
  { 222: }
  78,
  { 223: }
  78,
  { 224: }
  78,
  { 225: }
  88,
  { 226: }
  { 227: }
  79,
  { 228: }
  { 229: }
  { 230: }
  { 231: }
  84,
  { 232: }
  { 233: }
  { 234: }
  { 235: }
  { 236: }
  { 237: }
  { 238: }
  { 239: }
  30,
  78,
  { 240: }
  78,
  { 241: }
  78,
  { 242: }
  78,
  { 243: }
  78,
  { 244: }
  32,
  78,
  { 245: }
  36,
  78,
  { 246: }
  78,
  { 247: }
  78,
  { 248: }
  78,
  { 249: }
  35,
  78,
  { 250: }
  78,
  { 251: }
  78,
  { 252: }
  78,
  { 253: }
  78,
  { 254: }
  43,
  78,
  { 255: }
  78,
  { 256: }
  78,
  { 257: }
  78,
  { 258: }
  78,
  { 259: }
  78,
  { 260: }
  47,
  78,
  { 261: }
  44,
  78,
  { 262: }
  78,
  { 263: }
  78,
  { 264: }
  74,
  78,
  { 265: }
  67,
  78,
  { 266: }
  78,
  { 267: }
  78,
  { 268: }
  78,
  { 269: }
  78,
  { 270: }
  78,
  { 271: }
  78,
  { 272: }
  78,
  { 273: }
  78,
  { 274: }
  78,
  { 275: }
  78,
  { 276: }
  78,
  { 277: }
  { 278: }
  { 279: }
  { 280: }
  { 281: }
  { 282: }
  { 283: }
  { 284: }
  { 285: }
  78,
  { 286: }
  59,
  78,
  { 287: }
  78,
  { 288: }
  78,
  { 289: }
  78,
  { 290: }
  33,
  78,
  { 291: }
  78,
  { 292: }
  78,
  { 293: }
  78,
  { 294: }
  38,
  78,
  { 295: }
  46,
  78,
  { 296: }
  48,
  78,
  { 297: }
  78,
  { 298: }
  78,
  { 299: }
  78,
  { 300: }
  78,
  { 301: }
  78,
  { 302: }
  78,
  { 303: }
  73,
  78,
  { 304: }
  78,
  { 305: }
  78,
  { 306: }
  60,
  78,
  { 307: }
  78,
  { 308: }
  63,
  78,
  { 309: }
  78,
  { 310: }
  66,
  78,
  { 311: }
  78,
  { 312: }
  75,
  78,
  { 313: }
  77,
  78,
  { 314: }
  { 315: }
  { 316: }
  { 317: }
  { 318: }
  { 319: }
  76,
  78,
  { 320: }
  31,
  78,
  { 321: }
  78,
  { 322: }
  62,
  78,
  { 323: }
  50,
  78,
  { 324: }
  39,
  78,
  { 325: }
  37,
  78,
  { 326: }
  78,
  { 327: }
  78,
  { 328: }
  78,
  { 329: }
  78,
  { 330: }
  78,
  { 331: }
  78,
  { 332: }
  78,
  { 333: }
  78,
  { 334: }
  61,
  78,
  { 335: }
  78,
  { 336: }
  78,
  { 337: }
  { 338: }
  5,
  6,
  { 339: }
  4,
  { 340: }
  78,
  { 341: }
  58,
  78,
  { 342: }
  69,
  78,
  { 343: }
  78,
  { 344: }
  41,
  78,
  { 345: }
  78,
  { 346: }
  78,
  { 347: }
  55,
  78,
  { 348: }
  78,
  { 349: }
  78,
  { 350: }
  70,
  78,
  { 351: }
  4,
  6,
  { 352: }
  78,
  { 353: }
  56,
  78,
  { 354: }
  72,
  78,
  { 355: }
  54,
  78,
  { 356: }
  71,
  78,
  { 357: }
  64,
  78,
  { 358: }
  78,
  { 359: }
  57,
  78
);

yym : array [1..yynmatches] of Integer = (
{ 0: }
{ 1: }
{ 2: }
  1,
  94,
{ 3: }
  2,
{ 4: }
  22,
  94,
{ 5: }
  94,
{ 6: }
  7,
  94,
{ 7: }
  8,
  94,
{ 8: }
  9,
  94,
{ 9: }
  10,
  94,
{ 10: }
  11,
  94,
{ 11: }
  12,
  94,
{ 12: }
  13,
  94,
{ 13: }
  14,
  94,
{ 14: }
  15,
  94,
{ 15: }
  16,
  94,
{ 16: }
  29,
  94,
{ 17: }
  28,
  94,
{ 18: }
  19,
  94,
{ 19: }
  20,
  94,
{ 20: }
  21,
  94,
{ 21: }
  23,
  94,
{ 22: }
  24,
  94,
{ 23: }
  25,
  94,
{ 24: }
  26,
  94,
{ 25: }
  27,
  94,
{ 26: }
  78,
  94,
{ 27: }
  78,
  94,
{ 28: }
  78,
  94,
{ 29: }
  78,
  94,
{ 30: }
  78,
  94,
{ 31: }
  78,
  94,
{ 32: }
  78,
  94,
{ 33: }
  78,
  94,
{ 34: }
  78,
  94,
{ 35: }
  78,
  94,
{ 36: }
  78,
  94,
{ 37: }
  78,
  94,
{ 38: }
  78,
  94,
{ 39: }
  78,
  94,
{ 40: }
  78,
  94,
{ 41: }
  78,
  94,
{ 42: }
  78,
  94,
{ 43: }
  78,
  94,
{ 44: }
  78,
  94,
{ 45: }
  78,
  94,
{ 46: }
  78,
  94,
{ 47: }
  78,
  94,
{ 48: }
  78,
  94,
{ 49: }
  90,
  94,
{ 50: }
  94,
{ 51: }
  89,
  94,
{ 52: }
  94,
{ 53: }
  94,
{ 54: }
  94,
{ 55: }
  94,
{ 56: }
  3,
{ 57: }
{ 58: }
  65,
{ 59: }
  17,
{ 60: }
  18,
{ 61: }
  78,
{ 62: }
  78,
{ 63: }
  78,
{ 64: }
  78,
{ 65: }
  78,
{ 66: }
  78,
{ 67: }
  78,
{ 68: }
  78,
{ 69: }
  78,
{ 70: }
  78,
{ 71: }
  78,
{ 72: }
  78,
{ 73: }
  78,
{ 74: }
  78,
{ 75: }
  78,
{ 76: }
  78,
{ 77: }
  78,
{ 78: }
  78,
{ 79: }
  78,
{ 80: }
  78,
{ 81: }
  78,
{ 82: }
  78,
{ 83: }
  78,
{ 84: }
  78,
{ 85: }
  78,
{ 86: }
  78,
{ 87: }
  78,
{ 88: }
  78,
{ 89: }
  52,
  78,
{ 90: }
  78,
{ 91: }
  78,
{ 92: }
  78,
{ 93: }
  78,
{ 94: }
  78,
{ 95: }
  78,
{ 96: }
  78,
{ 97: }
  78,
{ 98: }
  78,
{ 99: }
  78,
{ 100: }
  78,
{ 101: }
  78,
{ 102: }
  78,
{ 103: }
  78,
{ 104: }
{ 105: }
  82,
{ 106: }
{ 107: }
  85,
{ 108: }
  90,
{ 109: }
  91,
{ 110: }
  83,
{ 111: }
  89,
{ 112: }
{ 113: }
{ 114: }
{ 115: }
{ 116: }
  93,
{ 117: }
{ 118: }
{ 119: }
{ 120: }
  6,
{ 121: }
{ 122: }
  78,
{ 123: }
  78,
{ 124: }
  78,
{ 125: }
  78,
{ 126: }
  78,
{ 127: }
  78,
{ 128: }
  78,
{ 129: }
  78,
{ 130: }
  78,
{ 131: }
  78,
{ 132: }
  78,
{ 133: }
  78,
{ 134: }
  78,
{ 135: }
  78,
{ 136: }
  78,
{ 137: }
  78,
{ 138: }
  78,
{ 139: }
  78,
{ 140: }
  78,
{ 141: }
  78,
{ 142: }
  78,
{ 143: }
  78,
{ 144: }
  78,
{ 145: }
  78,
{ 146: }
  78,
{ 147: }
  78,
{ 148: }
  78,
{ 149: }
  78,
{ 150: }
  78,
{ 151: }
  78,
{ 152: }
  53,
  78,
{ 153: }
  78,
{ 154: }
  78,
{ 155: }
  78,
{ 156: }
  68,
  78,
{ 157: }
  78,
{ 158: }
  78,
{ 159: }
  78,
{ 160: }
  78,
{ 161: }
  78,
{ 162: }
  78,
{ 163: }
  78,
{ 164: }
  78,
{ 165: }
  78,
{ 166: }
  81,
{ 167: }
{ 168: }
  86,
{ 169: }
{ 170: }
  80,
{ 171: }
{ 172: }
  87,
{ 173: }
  92,
{ 174: }
{ 175: }
{ 176: }
{ 177: }
{ 178: }
{ 179: }
{ 180: }
{ 181: }
  78,
{ 182: }
  78,
{ 183: }
  34,
  78,
{ 184: }
  49,
  78,
{ 185: }
  78,
{ 186: }
  78,
{ 187: }
  78,
{ 188: }
  78,
{ 189: }
  78,
{ 190: }
  78,
{ 191: }
  78,
{ 192: }
  78,
{ 193: }
  78,
{ 194: }
  78,
{ 195: }
  78,
{ 196: }
  78,
{ 197: }
  78,
{ 198: }
  78,
{ 199: }
  78,
{ 200: }
  78,
{ 201: }
  78,
{ 202: }
  40,
  78,
{ 203: }
  78,
{ 204: }
  78,
{ 205: }
  78,
{ 206: }
  42,
  78,
{ 207: }
  78,
{ 208: }
  45,
  78,
{ 209: }
  51,
  78,
{ 210: }
  78,
{ 211: }
  78,
{ 212: }
  78,
{ 213: }
  78,
{ 214: }
  78,
{ 215: }
  78,
{ 216: }
  78,
{ 217: }
  78,
{ 218: }
  78,
{ 219: }
  78,
{ 220: }
  78,
{ 221: }
  78,
{ 222: }
  78,
{ 223: }
  78,
{ 224: }
  78,
{ 225: }
  88,
{ 226: }
{ 227: }
  79,
{ 228: }
{ 229: }
{ 230: }
{ 231: }
  84,
{ 232: }
{ 233: }
{ 234: }
{ 235: }
{ 236: }
{ 237: }
{ 238: }
{ 239: }
  30,
  78,
{ 240: }
  78,
{ 241: }
  78,
{ 242: }
  78,
{ 243: }
  78,
{ 244: }
  32,
  78,
{ 245: }
  36,
  78,
{ 246: }
  78,
{ 247: }
  78,
{ 248: }
  78,
{ 249: }
  35,
  78,
{ 250: }
  78,
{ 251: }
  78,
{ 252: }
  78,
{ 253: }
  78,
{ 254: }
  43,
  78,
{ 255: }
  78,
{ 256: }
  78,
{ 257: }
  78,
{ 258: }
  78,
{ 259: }
  78,
{ 260: }
  47,
  78,
{ 261: }
  44,
  78,
{ 262: }
  78,
{ 263: }
  78,
{ 264: }
  74,
  78,
{ 265: }
  67,
  78,
{ 266: }
  78,
{ 267: }
  78,
{ 268: }
  78,
{ 269: }
  78,
{ 270: }
  78,
{ 271: }
  78,
{ 272: }
  78,
{ 273: }
  78,
{ 274: }
  78,
{ 275: }
  78,
{ 276: }
  78,
{ 277: }
{ 278: }
{ 279: }
{ 280: }
{ 281: }
{ 282: }
{ 283: }
{ 284: }
{ 285: }
  78,
{ 286: }
  59,
  78,
{ 287: }
  78,
{ 288: }
  78,
{ 289: }
  78,
{ 290: }
  33,
  78,
{ 291: }
  78,
{ 292: }
  78,
{ 293: }
  78,
{ 294: }
  38,
  78,
{ 295: }
  46,
  78,
{ 296: }
  48,
  78,
{ 297: }
  78,
{ 298: }
  78,
{ 299: }
  78,
{ 300: }
  78,
{ 301: }
  78,
{ 302: }
  78,
{ 303: }
  73,
  78,
{ 304: }
  78,
{ 305: }
  78,
{ 306: }
  60,
  78,
{ 307: }
  78,
{ 308: }
  63,
  78,
{ 309: }
  78,
{ 310: }
  66,
  78,
{ 311: }
  78,
{ 312: }
  75,
  78,
{ 313: }
  77,
  78,
{ 314: }
{ 315: }
{ 316: }
{ 317: }
{ 318: }
{ 319: }
  76,
  78,
{ 320: }
  31,
  78,
{ 321: }
  78,
{ 322: }
  62,
  78,
{ 323: }
  50,
  78,
{ 324: }
  39,
  78,
{ 325: }
  37,
  78,
{ 326: }
  78,
{ 327: }
  78,
{ 328: }
  78,
{ 329: }
  78,
{ 330: }
  78,
{ 331: }
  78,
{ 332: }
  78,
{ 333: }
  78,
{ 334: }
  61,
  78,
{ 335: }
  78,
{ 336: }
  78,
{ 337: }
{ 338: }
  5,
  6,
{ 339: }
  4,
{ 340: }
  78,
{ 341: }
  58,
  78,
{ 342: }
  69,
  78,
{ 343: }
  78,
{ 344: }
  41,
  78,
{ 345: }
  78,
{ 346: }
  78,
{ 347: }
  55,
  78,
{ 348: }
  78,
{ 349: }
  78,
{ 350: }
  70,
  78,
{ 351: }
  4,
  6,
{ 352: }
  78,
{ 353: }
  56,
  78,
{ 354: }
  72,
  78,
{ 355: }
  54,
  78,
{ 356: }
  71,
  78,
{ 357: }
  64,
  78,
{ 358: }
  78,
{ 359: }
  57,
  78
);

yyt : array [1..yyntrans] of YYTrec = (
{ 0: }
  ( cc: [ #1..#8,#11,#12,#14..#31,'!','$','?','@','\',
            '`',#127..#255 ]; s: 54),
  ( cc: [ #9,#13,' ' ]; s: 2),
  ( cc: [ #10 ]; s: 3),
  ( cc: [ '"' ]; s: 53),
  ( cc: [ '#' ]; s: 5),
  ( cc: [ '%' ]; s: 21),
  ( cc: [ '&' ]; s: 25),
  ( cc: [ '''' ]; s: 52),
  ( cc: [ '(' ]; s: 10),
  ( cc: [ ')' ]; s: 11),
  ( cc: [ '*' ]; s: 20),
  ( cc: [ '+' ]; s: 18),
  ( cc: [ ',' ]; s: 13),
  ( cc: [ '-' ]; s: 19),
  ( cc: [ '.' ]; s: 50),
  ( cc: [ '/' ]; s: 4),
  ( cc: [ '0' ]; s: 49),
  ( cc: [ '1'..'9' ]; s: 51),
  ( cc: [ ':' ]; s: 12),
  ( cc: [ ';' ]; s: 14),
  ( cc: [ '<' ]; s: 17),
  ( cc: [ '=' ]; s: 15),
  ( cc: [ '>' ]; s: 16),
  ( cc: [ 'A'..'E','G'..'N','P'..'S','U','W'..'Z','_',
            'g','h','j','k','q','x'..'z' ]; s: 48),
  ( cc: [ 'F' ]; s: 36),
  ( cc: [ 'O' ]; s: 47),
  ( cc: [ 'T' ]; s: 37),
  ( cc: [ 'V' ]; s: 44),
  ( cc: [ '[' ]; s: 8),
  ( cc: [ ']' ]; s: 9),
  ( cc: [ '^' ]; s: 24),
  ( cc: [ 'a' ]; s: 41),
  ( cc: [ 'b' ]; s: 31),
  ( cc: [ 'c' ]; s: 26),
  ( cc: [ 'd' ]; s: 29),
  ( cc: [ 'e' ]; s: 38),
  ( cc: [ 'f' ]; s: 28),
  ( cc: [ 'i' ]; s: 39),
  ( cc: [ 'l' ]; s: 35),
  ( cc: [ 'm' ]; s: 45),
  ( cc: [ 'n' ]; s: 43),
  ( cc: [ 'o' ]; s: 40),
  ( cc: [ 'p' ]; s: 42),
  ( cc: [ 'r' ]; s: 46),
  ( cc: [ 's' ]; s: 32),
  ( cc: [ 't' ]; s: 27),
  ( cc: [ 'u' ]; s: 34),
  ( cc: [ 'v' ]; s: 33),
  ( cc: [ 'w' ]; s: 30),
  ( cc: [ '{' ]; s: 6),
  ( cc: [ '|' ]; s: 23),
  ( cc: [ '}' ]; s: 7),
  ( cc: [ '~' ]; s: 22),
{ 1: }
  ( cc: [ #1..#8,#11,#12,#14..#31,'!','$','?','@','\',
            '`',#127..#255 ]; s: 54),
  ( cc: [ #9,#13,' ' ]; s: 2),
  ( cc: [ #10 ]; s: 3),
  ( cc: [ '"' ]; s: 53),
  ( cc: [ '#' ]; s: 55),
  ( cc: [ '%' ]; s: 21),
  ( cc: [ '&' ]; s: 25),
  ( cc: [ '''' ]; s: 52),
  ( cc: [ '(' ]; s: 10),
  ( cc: [ ')' ]; s: 11),
  ( cc: [ '*' ]; s: 20),
  ( cc: [ '+' ]; s: 18),
  ( cc: [ ',' ]; s: 13),
  ( cc: [ '-' ]; s: 19),
  ( cc: [ '.' ]; s: 50),
  ( cc: [ '/' ]; s: 4),
  ( cc: [ '0' ]; s: 49),
  ( cc: [ '1'..'9' ]; s: 51),
  ( cc: [ ':' ]; s: 12),
  ( cc: [ ';' ]; s: 14),
  ( cc: [ '<' ]; s: 17),
  ( cc: [ '=' ]; s: 15),
  ( cc: [ '>' ]; s: 16),
  ( cc: [ 'A'..'E','G'..'N','P'..'S','U','W'..'Z','_',
            'g','h','j','k','q','x'..'z' ]; s: 48),
  ( cc: [ 'F' ]; s: 36),
  ( cc: [ 'O' ]; s: 47),
  ( cc: [ 'T' ]; s: 37),
  ( cc: [ 'V' ]; s: 44),
  ( cc: [ '[' ]; s: 8),
  ( cc: [ ']' ]; s: 9),
  ( cc: [ '^' ]; s: 24),
  ( cc: [ 'a' ]; s: 41),
  ( cc: [ 'b' ]; s: 31),
  ( cc: [ 'c' ]; s: 26),
  ( cc: [ 'd' ]; s: 29),
  ( cc: [ 'e' ]; s: 38),
  ( cc: [ 'f' ]; s: 28),
  ( cc: [ 'i' ]; s: 39),
  ( cc: [ 'l' ]; s: 35),
  ( cc: [ 'm' ]; s: 45),
  ( cc: [ 'n' ]; s: 43),
  ( cc: [ 'o' ]; s: 40),
  ( cc: [ 'p' ]; s: 42),
  ( cc: [ 'r' ]; s: 46),
  ( cc: [ 's' ]; s: 32),
  ( cc: [ 't' ]; s: 27),
  ( cc: [ 'u' ]; s: 34),
  ( cc: [ 'v' ]; s: 33),
  ( cc: [ 'w' ]; s: 30),
  ( cc: [ '{' ]; s: 6),
  ( cc: [ '|' ]; s: 23),
  ( cc: [ '}' ]; s: 7),
  ( cc: [ '~' ]; s: 22),
{ 2: }
{ 3: }
{ 4: }
  ( cc: [ '/' ]; s: 56),
{ 5: }
  ( cc: [ 'p' ]; s: 57),
{ 6: }
{ 7: }
{ 8: }
{ 9: }
{ 10: }
{ 11: }
{ 12: }
  ( cc: [ ':' ]; s: 58),
{ 13: }
{ 14: }
{ 15: }
{ 16: }
  ( cc: [ '>' ]; s: 59),
{ 17: }
  ( cc: [ '<' ]; s: 60),
{ 18: }
{ 19: }
{ 20: }
{ 21: }
{ 22: }
{ 23: }
{ 24: }
{ 25: }
{ 26: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'g','i'..'n','p'..'t',
            'v'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 63),
  ( cc: [ 'h' ]; s: 62),
  ( cc: [ 'o' ]; s: 61),
  ( cc: [ 'u' ]; s: 64),
{ 27: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'x','z' ]; s: 65),
  ( cc: [ 'r' ]; s: 67),
  ( cc: [ 'y' ]; s: 66),
{ 28: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'h','j','k','m'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 70),
  ( cc: [ 'i' ]; s: 69),
  ( cc: [ 'l' ]; s: 68),
{ 29: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 72),
  ( cc: [ 'o' ]; s: 71),
{ 30: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'r','t'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 73),
  ( cc: [ 's' ]; s: 74),
{ 31: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 75),
{ 32: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f','g','i'..'s',
            'v','x'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 80),
  ( cc: [ 'h' ]; s: 77),
  ( cc: [ 't' ]; s: 76),
  ( cc: [ 'u' ]; s: 79),
  ( cc: [ 'w' ]; s: 78),
{ 33: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 82),
  ( cc: [ 'o' ]; s: 81),
{ 34: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 83),
{ 35: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 84),
{ 36: }
  ( cc: [ '0'..'9','B'..'Z','_','a'..'z' ]; s: 65),
  ( cc: [ 'A' ]; s: 85),
{ 37: }
  ( cc: [ '0'..'9','A'..'Q','S'..'Z','_','a'..'z' ]; s: 65),
  ( cc: [ 'R' ]; s: 86),
{ 38: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'w','y','z' ]; s: 65),
  ( cc: [ 'n' ]; s: 87),
  ( cc: [ 'x' ]; s: 88),
{ 39: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 89),
{ 40: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'m','o'..'t',
            'v'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 91),
  ( cc: [ 'n' ]; s: 92),
  ( cc: [ 'u' ]; s: 90),
{ 41: }
  ( cc: [ '0'..'9','A'..'Z','_','a','c'..'m','o'..'s',
            'u'..'z' ]; s: 65),
  ( cc: [ 'b' ]; s: 93),
  ( cc: [ 'n' ]; s: 94),
  ( cc: [ 't' ]; s: 95),
{ 42: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s','t','v'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 97),
  ( cc: [ 'u' ]; s: 96),
{ 43: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 98),
{ 44: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 99),
{ 45: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 100),
{ 46: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 102),
  ( cc: [ 'e' ]; s: 101),
{ 47: }
  ( cc: [ '0'..'9','A'..'Z','_','a','c'..'z' ]; s: 65),
  ( cc: [ 'b' ]; s: 103),
{ 48: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 49: }
  ( cc: [ '.' ]; s: 105),
  ( cc: [ '0'..'7' ]; s: 108),
  ( cc: [ '8','9' ]; s: 104),
  ( cc: [ 'D','d' ]; s: 107),
  ( cc: [ 'E','e' ]; s: 106),
  ( cc: [ 'X','x' ]; s: 109),
{ 50: }
  ( cc: [ '0'..'9' ]; s: 110),
{ 51: }
  ( cc: [ '.' ]; s: 105),
  ( cc: [ '0'..'9' ]; s: 111),
  ( cc: [ 'D','d' ]; s: 107),
  ( cc: [ 'E','e' ]; s: 106),
{ 52: }
  ( cc: [ #1..#8,#11..'&','('..'[',']'..#255 ]; s: 112),
  ( cc: [ '\' ]; s: 113),
{ 53: }
  ( cc: [ #1..#8,#11..'!','#'..'[',']'..#255 ]; s: 114),
  ( cc: [ '"' ]; s: 116),
  ( cc: [ '\' ]; s: 115),
{ 54: }
{ 55: }
  ( cc: [ #1..#9,#11..'k','m'..'o','q'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ 'l' ]; s: 118),
  ( cc: [ 'p' ]; s: 117),
{ 56: }
  ( cc: [ #1..#9,#11..#255 ]; s: 56),
{ 57: }
  ( cc: [ 'r' ]; s: 121),
{ 58: }
{ 59: }
{ 60: }
{ 61: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 122),
{ 62: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 123),
{ 63: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'r','t'..'z' ]; s: 65),
  ( cc: [ 's' ]; s: 124),
{ 64: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'r','t'..'z' ]; s: 65),
  ( cc: [ 's' ]; s: 125),
{ 65: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 66: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'o','q'..'z' ]; s: 65),
  ( cc: [ 'p' ]; s: 126),
{ 67: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 127),
{ 68: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 128),
{ 69: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'w','y','z' ]; s: 65),
  ( cc: [ 'x' ]; s: 129),
{ 70: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 130),
{ 71: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 131),
{ 72: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'e','g'..'z' ]; s: 65),
  ( cc: [ 'f' ]; s: 132),
{ 73: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'g','i'..'z' ]; s: 65),
  ( cc: [ 'h' ]; s: 133),
{ 74: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 134),
{ 75: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 135),
{ 76: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 136),
{ 77: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 137),
{ 78: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 138),
{ 79: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'o','q'..'z' ]; s: 65),
  ( cc: [ 'p' ]; s: 139),
{ 80: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'p','r'..'z' ]; s: 65),
  ( cc: [ 'q' ]; s: 140),
{ 81: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 141),
{ 82: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'k','m'..'z' ]; s: 65),
  ( cc: [ 'l' ]; s: 142),
{ 83: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'r','t'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 144),
  ( cc: [ 's' ]; s: 143),
{ 84: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 145),
{ 85: }
  ( cc: [ '0'..'9','A'..'K','M'..'Z','_','a'..'z' ]; s: 65),
  ( cc: [ 'L' ]; s: 146),
{ 86: }
  ( cc: [ '0'..'9','A'..'T','V'..'Z','_','a'..'z' ]; s: 65),
  ( cc: [ 'U' ]; s: 147),
{ 87: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 148),
{ 88: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 149),
{ 89: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'s','u'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 151),
  ( cc: [ 't' ]; s: 150),
{ 90: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 152),
{ 91: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 153),
{ 92: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 154),
{ 93: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'r','t'..'z' ]; s: 65),
  ( cc: [ 's' ]; s: 155),
{ 94: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'x','z' ]; s: 65),
  ( cc: [ 'y' ]; s: 156),
{ 95: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 157),
{ 96: }
  ( cc: [ '0'..'9','A'..'Z','_','a','c'..'z' ]; s: 65),
  ( cc: [ 'b' ]; s: 158),
{ 97: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 159),
{ 98: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 160),
{ 99: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'k','m'..'z' ]; s: 65),
  ( cc: [ 'l' ]; s: 161),
{ 100: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'c','e'..'z' ]; s: 65),
  ( cc: [ 'd' ]; s: 162),
{ 101: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 163),
{ 102: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 164),
{ 103: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'i','k'..'z' ]; s: 65),
  ( cc: [ 'j' ]; s: 165),
{ 104: }
  ( cc: [ '.' ]; s: 105),
  ( cc: [ '0'..'9' ]; s: 104),
  ( cc: [ 'D','d' ]; s: 107),
  ( cc: [ 'E','e' ]; s: 106),
{ 105: }
  ( cc: [ '0'..'9' ]; s: 166),
  ( cc: [ 'D','d' ]; s: 168),
  ( cc: [ 'E','e' ]; s: 167),
{ 106: }
  ( cc: [ '''' ]; s: 169),
  ( cc: [ '0'..'9' ]; s: 170),
{ 107: }
{ 108: }
  ( cc: [ '.' ]; s: 105),
  ( cc: [ '0'..'7' ]; s: 108),
  ( cc: [ '8','9' ]; s: 104),
  ( cc: [ 'D','d' ]; s: 107),
  ( cc: [ 'E','e' ]; s: 106),
{ 109: }
  ( cc: [ '0'..'9','A'..'F','a'..'f' ]; s: 109),
{ 110: }
  ( cc: [ '0'..'9' ]; s: 110),
  ( cc: [ 'D','d' ]; s: 172),
  ( cc: [ 'E','e' ]; s: 171),
{ 111: }
  ( cc: [ '.' ]; s: 105),
  ( cc: [ '0'..'9' ]; s: 111),
  ( cc: [ 'D','d' ]; s: 107),
  ( cc: [ 'E','e' ]; s: 106),
{ 112: }
  ( cc: [ '''' ]; s: 173),
{ 113: }
  ( cc: [ '"','''','?','\','a','b','f','n','r','t',
            'v' ]; s: 112),
  ( cc: [ '0'..'7' ]; s: 174),
  ( cc: [ 'X','x' ]; s: 175),
{ 114: }
  ( cc: [ #1..#8,#11..'!','#'..'[',']'..#255 ]; s: 114),
  ( cc: [ '"' ]; s: 116),
  ( cc: [ '\' ]; s: 115),
{ 115: }
  ( cc: [ '"','''','?','\','a','b','f','n','r','t',
            'v' ]; s: 114),
  ( cc: [ '0'..'7' ]; s: 176),
  ( cc: [ 'X','x' ]; s: 177),
{ 116: }
{ 117: }
  ( cc: [ #1..#9,#11..'q','s'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ 'r' ]; s: 178),
{ 118: }
  ( cc: [ #1..#9,#11..'h','j'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ 'i' ]; s: 179),
{ 119: }
  ( cc: [ #1..#9,#11..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
{ 120: }
{ 121: }
  ( cc: [ 'a' ]; s: 180),
{ 122: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'r','u'..'z' ]; s: 65),
  ( cc: [ 's' ]; s: 181),
  ( cc: [ 't' ]; s: 182),
{ 123: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 183),
{ 124: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 184),
{ 125: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 185),
{ 126: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 186),
{ 127: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 187),
{ 128: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 188),
{ 129: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 189),
{ 130: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 190),
{ 131: }
  ( cc: [ '0'..'9','A'..'Z','_','a','c'..'z' ]; s: 65),
  ( cc: [ 'b' ]; s: 191),
{ 132: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 192),
{ 133: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 193),
{ 134: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 194),
{ 135: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'k','m'..'z' ]; s: 65),
  ( cc: [ 'l' ]; s: 195),
{ 136: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 196),
  ( cc: [ 'u' ]; s: 197),
{ 137: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 198),
{ 138: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 199),
{ 139: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'o','q'..'z' ]; s: 65),
  ( cc: [ 'p' ]; s: 200),
{ 140: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 201),
{ 141: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'c','e'..'z' ]; s: 65),
  ( cc: [ 'd' ]; s: 202),
{ 142: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 203),
{ 143: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 204),
{ 144: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 205),
{ 145: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'f','h'..'z' ]; s: 65),
  ( cc: [ 'g' ]; s: 206),
{ 146: }
  ( cc: [ '0'..'9','A'..'R','T'..'Z','_','a'..'z' ]; s: 65),
  ( cc: [ 'S' ]; s: 207),
{ 147: }
  ( cc: [ '0'..'9','A'..'D','F'..'Z','_','a'..'z' ]; s: 65),
  ( cc: [ 'E' ]; s: 208),
{ 148: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'l','n'..'z' ]; s: 65),
  ( cc: [ 'm' ]; s: 209),
{ 149: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 210),
{ 150: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 211),
{ 151: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 212),
{ 152: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 153: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 213),
{ 154: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'v','x'..'z' ]; s: 65),
  ( cc: [ 'w' ]; s: 214),
{ 155: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 215),
{ 156: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 157: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 216),
{ 158: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'k','m'..'z' ]; s: 65),
  ( cc: [ 'l' ]; s: 217),
{ 159: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'u','w'..'z' ]; s: 65),
  ( cc: [ 'v' ]; s: 218),
{ 160: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 219),
{ 161: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 220),
{ 162: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 221),
{ 163: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'c','e'..'z' ]; s: 65),
  ( cc: [ 'd' ]; s: 222),
{ 164: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'r','t'..'z' ]; s: 65),
  ( cc: [ 's' ]; s: 223),
{ 165: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 224),
{ 166: }
  ( cc: [ '0'..'9' ]; s: 166),
  ( cc: [ 'D','d' ]; s: 225),
  ( cc: [ 'E','e' ]; s: 167),
{ 167: }
  ( cc: [ '''' ]; s: 226),
  ( cc: [ '0'..'9' ]; s: 227),
{ 168: }
{ 169: }
  ( cc: [ '''' ]; s: 228),
  ( cc: [ '-' ]; s: 229),
{ 170: }
  ( cc: [ '0'..'9' ]; s: 170),
{ 171: }
  ( cc: [ '''' ]; s: 230),
  ( cc: [ '0'..'9' ]; s: 231),
{ 172: }
{ 173: }
{ 174: }
  ( cc: [ '''' ]; s: 173),
  ( cc: [ '0'..'7' ]; s: 232),
{ 175: }
  ( cc: [ '0'..'9','A'..'F','a'..'f' ]; s: 233),
{ 176: }
  ( cc: [ #1..#8,#11..'!','#'..'/','8'..'[',']'..#255 ]; s: 114),
  ( cc: [ '"' ]; s: 116),
  ( cc: [ '0'..'7' ]; s: 234),
  ( cc: [ '\' ]; s: 115),
{ 177: }
  ( cc: [ '0'..'9','A'..'F','a'..'f' ]; s: 235),
{ 178: }
  ( cc: [ #1..#9,#11..'`','b'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ 'a' ]; s: 236),
{ 179: }
  ( cc: [ #1..#9,#11..'m','o'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ 'n' ]; s: 237),
{ 180: }
  ( cc: [ 'g' ]; s: 238),
{ 181: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 239),
{ 182: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 240),
{ 183: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 184: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 185: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 241),
{ 186: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'c','e'..'z' ]; s: 65),
  ( cc: [ 'd' ]; s: 242),
{ 187: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 243),
{ 188: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 244),
{ 189: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'c','e'..'z' ]; s: 65),
  ( cc: [ 'd' ]; s: 245),
{ 190: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 246),
{ 191: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'k','m'..'z' ]; s: 65),
  ( cc: [ 'l' ]; s: 247),
{ 192: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 248),
{ 193: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 249),
{ 194: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 250),
{ 195: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 251),
{ 196: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 252),
{ 197: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 253),
{ 198: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 254),
{ 199: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 255),
{ 200: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 256),
{ 201: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 257),
{ 202: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 203: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 258),
{ 204: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'f','h'..'z' ]; s: 65),
  ( cc: [ 'g' ]; s: 259),
{ 205: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 260),
{ 206: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 207: }
  ( cc: [ '0'..'9','A'..'D','F'..'Z','_','a'..'z' ]; s: 65),
  ( cc: [ 'E' ]; s: 261),
{ 208: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 209: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 210: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'o','q'..'z' ]; s: 65),
  ( cc: [ 'p' ]; s: 262),
{ 211: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 263),
{ 212: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 264),
{ 213: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 265),
{ 214: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 266),
{ 215: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 267),
{ 216: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 268),
{ 217: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 269),
{ 218: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 270),
{ 219: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'u','w'..'z' ]; s: 65),
  ( cc: [ 'v' ]; s: 271),
{ 220: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 272),
{ 221: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'k','m'..'z' ]; s: 65),
  ( cc: [ 'l' ]; s: 273),
{ 222: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 274),
{ 223: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 275),
{ 224: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 276),
{ 225: }
{ 226: }
  ( cc: [ '''' ]; s: 277),
  ( cc: [ '-' ]; s: 278),
{ 227: }
  ( cc: [ '0'..'9' ]; s: 227),
{ 228: }
  ( cc: [ '''' ]; s: 228),
  ( cc: [ '0'..'9' ]; s: 170),
{ 229: }
  ( cc: [ '''' ]; s: 279),
{ 230: }
  ( cc: [ '''' ]; s: 280),
  ( cc: [ '-' ]; s: 281),
{ 231: }
  ( cc: [ '0'..'9' ]; s: 231),
{ 232: }
  ( cc: [ '''' ]; s: 173),
  ( cc: [ '0'..'7' ]; s: 112),
{ 233: }
  ( cc: [ '''' ]; s: 173),
  ( cc: [ '0'..'9','A'..'F','a'..'f' ]; s: 112),
{ 234: }
  ( cc: [ #1..#8,#11..'!','#'..'[',']'..#255 ]; s: 114),
  ( cc: [ '"' ]; s: 116),
  ( cc: [ '\' ]; s: 115),
{ 235: }
  ( cc: [ #1..#8,#11..'!','#'..'[',']'..#255 ]; s: 114),
  ( cc: [ '"' ]; s: 116),
  ( cc: [ '\' ]; s: 115),
{ 236: }
  ( cc: [ #1..#9,#11..'f','h'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ 'g' ]; s: 282),
{ 237: }
  ( cc: [ #1..#9,#11..'d','f'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ 'e' ]; s: 283),
{ 238: }
  ( cc: [ 'm' ]; s: 284),
{ 239: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 240: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'w','y','z' ]; s: 65),
  ( cc: [ 'x' ]; s: 285),
{ 241: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'l','n'..'z' ]; s: 65),
  ( cc: [ 'm' ]; s: 286),
{ 242: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 287),
{ 243: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 288),
{ 244: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 245: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 246: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 289),
{ 247: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 290),
{ 248: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'k','m'..'z' ]; s: 65),
  ( cc: [ 'l' ]; s: 291),
{ 249: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 250: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 292),
{ 251: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 293),
{ 252: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'f','h'..'z' ]; s: 65),
  ( cc: [ 'g' ]; s: 294),
{ 253: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 295),
{ 254: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 255: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'g','i'..'z' ]; s: 65),
  ( cc: [ 'h' ]; s: 296),
{ 256: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'q','s'..'z' ]; s: 65),
  ( cc: [ 'r' ]; s: 297),
{ 257: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 298),
{ 258: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 299),
{ 259: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 300),
{ 260: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 261: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 262: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 301),
{ 263: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'e','g'..'z' ]; s: 65),
  ( cc: [ 'f' ]; s: 302),
{ 264: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 265: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 266: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'x','z' ]; s: 65),
  ( cc: [ 'y' ]; s: 303),
{ 267: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 304),
{ 268: }
  ( cc: [ '0'..'9','A'..'Z','_','a','c'..'z' ]; s: 65),
  ( cc: [ 'b' ]; s: 305),
{ 269: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 306),
{ 270: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 307),
{ 271: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 308),
{ 272: }
  ( cc: [ '0'..'9','A','C'..'Z','_','a'..'z' ]; s: 65),
  ( cc: [ 'B' ]; s: 309),
{ 273: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 310),
{ 274: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 311),
{ 275: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'r','t'..'z' ]; s: 65),
  ( cc: [ 's' ]; s: 312),
{ 276: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 313),
{ 277: }
  ( cc: [ '''' ]; s: 277),
  ( cc: [ '0'..'9' ]; s: 227),
{ 278: }
  ( cc: [ '''' ]; s: 314),
{ 279: }
  ( cc: [ '0'..'9' ]; s: 170),
{ 280: }
  ( cc: [ '''' ]; s: 280),
  ( cc: [ '0'..'9' ]; s: 231),
{ 281: }
  ( cc: [ '''' ]; s: 315),
{ 282: }
  ( cc: [ #1..#9,#11..'l','n'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ 'm' ]; s: 316),
{ 283: }
  ( cc: [ #1..#9,#11..#31,'!'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ ' ' ]; s: 317),
{ 284: }
  ( cc: [ 'a' ]; s: 318),
{ 285: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 319),
{ 286: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 287: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'e','g'..'z' ]; s: 65),
  ( cc: [ 'f' ]; s: 320),
{ 288: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 321),
{ 289: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'x','z' ]; s: 65),
  ( cc: [ 'y' ]; s: 322),
{ 290: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 291: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 323),
{ 292: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'f','h'..'z' ]; s: 65),
  ( cc: [ 'g' ]; s: 324),
{ 293: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 325),
{ 294: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 295: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 296: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 297: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 326),
{ 298: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 327),
{ 299: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'x','z' ]; s: 65),
  ( cc: [ 'y' ]; s: 328),
{ 300: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 329),
{ 301: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'h','j'..'z' ]; s: 65),
  ( cc: [ 'i' ]; s: 330),
{ 302: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 331),
{ 303: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 304: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 332),
{ 305: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'t','v'..'z' ]; s: 65),
  ( cc: [ 'u' ]; s: 333),
{ 306: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 307: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 334),
{ 308: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 309: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 335),
{ 310: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 311: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'k','m'..'z' ]; s: 65),
  ( cc: [ 'l' ]; s: 336),
{ 312: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 313: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 314: }
  ( cc: [ '0'..'9' ]; s: 227),
{ 315: }
  ( cc: [ '0'..'9' ]; s: 231),
{ 316: }
  ( cc: [ #1..#9,#11..'`','b'..#255 ]; s: 119),
  ( cc: [ #10 ]; s: 120),
  ( cc: [ 'a' ]; s: 337),
{ 317: }
  ( cc: [ #1..#9,#11..#255 ]; s: 317),
  ( cc: [ #10 ]; s: 338),
{ 318: }
  ( cc: [ #1..#9,#11..#255 ]; s: 318),
  ( cc: [ #10 ]; s: 339),
{ 319: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 320: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 321: }
  ( cc: [ '0'..'9','A'..'Z','_','b'..'z' ]; s: 65),
  ( cc: [ 'a' ]; s: 340),
{ 322: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 323: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 324: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 325: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 326: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'r','t'..'z' ]; s: 65),
  ( cc: [ 's' ]; s: 341),
{ 327: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 342),
{ 328: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'o','q'..'z' ]; s: 65),
  ( cc: [ 'p' ]; s: 343),
{ 329: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'c','e'..'z' ]; s: 65),
  ( cc: [ 'd' ]; s: 344),
{ 330: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'n','p'..'z' ]; s: 65),
  ( cc: [ 'o' ]; s: 345),
{ 331: }
  ( cc: [ '0'..'9','A'..'Z','_','a','b','d'..'z' ]; s: 65),
  ( cc: [ 'c' ]; s: 346),
{ 332: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 347),
{ 333: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'s','u'..'z' ]; s: 65),
  ( cc: [ 't' ]; s: 348),
{ 334: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 335: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'r','t'..'z' ]; s: 65),
  ( cc: [ 's' ]; s: 349),
{ 336: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'x','z' ]; s: 65),
  ( cc: [ 'y' ]; s: 350),
{ 337: }
  ( cc: [ #1..#9,#11..#255 ]; s: 337),
  ( cc: [ #10 ]; s: 351),
{ 338: }
{ 339: }
{ 340: }
  ( cc: [ '0'..'9','A'..'Z','_','a','c'..'z' ]; s: 65),
  ( cc: [ 'b' ]; s: 352),
{ 341: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 342: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 343: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 353),
{ 344: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 345: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'m','o'..'z' ]; s: 65),
  ( cc: [ 'n' ]; s: 354),
{ 346: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 355),
{ 347: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 348: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 356),
{ 349: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 357),
{ 350: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 351: }
{ 352: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'k','m'..'z' ]; s: 65),
  ( cc: [ 'l' ]; s: 358),
{ 353: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 354: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 355: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 356: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 357: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65),
{ 358: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'d','f'..'z' ]; s: 65),
  ( cc: [ 'e' ]; s: 359),
{ 359: }
  ( cc: [ '0'..'9','A'..'Z','_','a'..'z' ]; s: 65)
);

yykl : array [0..yynstates-1] of Integer = (
{ 0: } 1,
{ 1: } 1,
{ 2: } 1,
{ 3: } 3,
{ 4: } 4,
{ 5: } 6,
{ 6: } 7,
{ 7: } 9,
{ 8: } 11,
{ 9: } 13,
{ 10: } 15,
{ 11: } 17,
{ 12: } 19,
{ 13: } 21,
{ 14: } 23,
{ 15: } 25,
{ 16: } 27,
{ 17: } 29,
{ 18: } 31,
{ 19: } 33,
{ 20: } 35,
{ 21: } 37,
{ 22: } 39,
{ 23: } 41,
{ 24: } 43,
{ 25: } 45,
{ 26: } 47,
{ 27: } 49,
{ 28: } 51,
{ 29: } 53,
{ 30: } 55,
{ 31: } 57,
{ 32: } 59,
{ 33: } 61,
{ 34: } 63,
{ 35: } 65,
{ 36: } 67,
{ 37: } 69,
{ 38: } 71,
{ 39: } 73,
{ 40: } 75,
{ 41: } 77,
{ 42: } 79,
{ 43: } 81,
{ 44: } 83,
{ 45: } 85,
{ 46: } 87,
{ 47: } 89,
{ 48: } 91,
{ 49: } 93,
{ 50: } 95,
{ 51: } 96,
{ 52: } 98,
{ 53: } 99,
{ 54: } 100,
{ 55: } 101,
{ 56: } 102,
{ 57: } 103,
{ 58: } 103,
{ 59: } 104,
{ 60: } 105,
{ 61: } 106,
{ 62: } 107,
{ 63: } 108,
{ 64: } 109,
{ 65: } 110,
{ 66: } 111,
{ 67: } 112,
{ 68: } 113,
{ 69: } 114,
{ 70: } 115,
{ 71: } 116,
{ 72: } 117,
{ 73: } 118,
{ 74: } 119,
{ 75: } 120,
{ 76: } 121,
{ 77: } 122,
{ 78: } 123,
{ 79: } 124,
{ 80: } 125,
{ 81: } 126,
{ 82: } 127,
{ 83: } 128,
{ 84: } 129,
{ 85: } 130,
{ 86: } 131,
{ 87: } 132,
{ 88: } 133,
{ 89: } 134,
{ 90: } 136,
{ 91: } 137,
{ 92: } 138,
{ 93: } 139,
{ 94: } 140,
{ 95: } 141,
{ 96: } 142,
{ 97: } 143,
{ 98: } 144,
{ 99: } 145,
{ 100: } 146,
{ 101: } 147,
{ 102: } 148,
{ 103: } 149,
{ 104: } 150,
{ 105: } 150,
{ 106: } 151,
{ 107: } 151,
{ 108: } 152,
{ 109: } 153,
{ 110: } 154,
{ 111: } 155,
{ 112: } 156,
{ 113: } 156,
{ 114: } 156,
{ 115: } 156,
{ 116: } 156,
{ 117: } 157,
{ 118: } 157,
{ 119: } 157,
{ 120: } 157,
{ 121: } 158,
{ 122: } 158,
{ 123: } 159,
{ 124: } 160,
{ 125: } 161,
{ 126: } 162,
{ 127: } 163,
{ 128: } 164,
{ 129: } 165,
{ 130: } 166,
{ 131: } 167,
{ 132: } 168,
{ 133: } 169,
{ 134: } 170,
{ 135: } 171,
{ 136: } 172,
{ 137: } 173,
{ 138: } 174,
{ 139: } 175,
{ 140: } 176,
{ 141: } 177,
{ 142: } 178,
{ 143: } 179,
{ 144: } 180,
{ 145: } 181,
{ 146: } 182,
{ 147: } 183,
{ 148: } 184,
{ 149: } 185,
{ 150: } 186,
{ 151: } 187,
{ 152: } 188,
{ 153: } 190,
{ 154: } 191,
{ 155: } 192,
{ 156: } 193,
{ 157: } 195,
{ 158: } 196,
{ 159: } 197,
{ 160: } 198,
{ 161: } 199,
{ 162: } 200,
{ 163: } 201,
{ 164: } 202,
{ 165: } 203,
{ 166: } 204,
{ 167: } 205,
{ 168: } 205,
{ 169: } 206,
{ 170: } 206,
{ 171: } 207,
{ 172: } 207,
{ 173: } 208,
{ 174: } 209,
{ 175: } 209,
{ 176: } 209,
{ 177: } 209,
{ 178: } 209,
{ 179: } 209,
{ 180: } 209,
{ 181: } 209,
{ 182: } 210,
{ 183: } 211,
{ 184: } 213,
{ 185: } 215,
{ 186: } 216,
{ 187: } 217,
{ 188: } 218,
{ 189: } 219,
{ 190: } 220,
{ 191: } 221,
{ 192: } 222,
{ 193: } 223,
{ 194: } 224,
{ 195: } 225,
{ 196: } 226,
{ 197: } 227,
{ 198: } 228,
{ 199: } 229,
{ 200: } 230,
{ 201: } 231,
{ 202: } 232,
{ 203: } 234,
{ 204: } 235,
{ 205: } 236,
{ 206: } 237,
{ 207: } 239,
{ 208: } 240,
{ 209: } 242,
{ 210: } 244,
{ 211: } 245,
{ 212: } 246,
{ 213: } 247,
{ 214: } 248,
{ 215: } 249,
{ 216: } 250,
{ 217: } 251,
{ 218: } 252,
{ 219: } 253,
{ 220: } 254,
{ 221: } 255,
{ 222: } 256,
{ 223: } 257,
{ 224: } 258,
{ 225: } 259,
{ 226: } 260,
{ 227: } 260,
{ 228: } 261,
{ 229: } 261,
{ 230: } 261,
{ 231: } 261,
{ 232: } 262,
{ 233: } 262,
{ 234: } 262,
{ 235: } 262,
{ 236: } 262,
{ 237: } 262,
{ 238: } 262,
{ 239: } 262,
{ 240: } 264,
{ 241: } 265,
{ 242: } 266,
{ 243: } 267,
{ 244: } 268,
{ 245: } 270,
{ 246: } 272,
{ 247: } 273,
{ 248: } 274,
{ 249: } 275,
{ 250: } 277,
{ 251: } 278,
{ 252: } 279,
{ 253: } 280,
{ 254: } 281,
{ 255: } 283,
{ 256: } 284,
{ 257: } 285,
{ 258: } 286,
{ 259: } 287,
{ 260: } 288,
{ 261: } 290,
{ 262: } 292,
{ 263: } 293,
{ 264: } 294,
{ 265: } 296,
{ 266: } 298,
{ 267: } 299,
{ 268: } 300,
{ 269: } 301,
{ 270: } 302,
{ 271: } 303,
{ 272: } 304,
{ 273: } 305,
{ 274: } 306,
{ 275: } 307,
{ 276: } 308,
{ 277: } 309,
{ 278: } 309,
{ 279: } 309,
{ 280: } 309,
{ 281: } 309,
{ 282: } 309,
{ 283: } 309,
{ 284: } 309,
{ 285: } 309,
{ 286: } 310,
{ 287: } 312,
{ 288: } 313,
{ 289: } 314,
{ 290: } 315,
{ 291: } 317,
{ 292: } 318,
{ 293: } 319,
{ 294: } 320,
{ 295: } 322,
{ 296: } 324,
{ 297: } 326,
{ 298: } 327,
{ 299: } 328,
{ 300: } 329,
{ 301: } 330,
{ 302: } 331,
{ 303: } 332,
{ 304: } 334,
{ 305: } 335,
{ 306: } 336,
{ 307: } 338,
{ 308: } 339,
{ 309: } 341,
{ 310: } 342,
{ 311: } 344,
{ 312: } 345,
{ 313: } 347,
{ 314: } 349,
{ 315: } 349,
{ 316: } 349,
{ 317: } 349,
{ 318: } 349,
{ 319: } 349,
{ 320: } 351,
{ 321: } 353,
{ 322: } 354,
{ 323: } 356,
{ 324: } 358,
{ 325: } 360,
{ 326: } 362,
{ 327: } 363,
{ 328: } 364,
{ 329: } 365,
{ 330: } 366,
{ 331: } 367,
{ 332: } 368,
{ 333: } 369,
{ 334: } 370,
{ 335: } 372,
{ 336: } 373,
{ 337: } 374,
{ 338: } 374,
{ 339: } 376,
{ 340: } 377,
{ 341: } 378,
{ 342: } 380,
{ 343: } 382,
{ 344: } 383,
{ 345: } 385,
{ 346: } 386,
{ 347: } 387,
{ 348: } 389,
{ 349: } 390,
{ 350: } 391,
{ 351: } 393,
{ 352: } 395,
{ 353: } 396,
{ 354: } 398,
{ 355: } 400,
{ 356: } 402,
{ 357: } 404,
{ 358: } 406,
{ 359: } 407
);

yykh : array [0..yynstates-1] of Integer = (
{ 0: } 0,
{ 1: } 0,
{ 2: } 2,
{ 3: } 3,
{ 4: } 5,
{ 5: } 6,
{ 6: } 8,
{ 7: } 10,
{ 8: } 12,
{ 9: } 14,
{ 10: } 16,
{ 11: } 18,
{ 12: } 20,
{ 13: } 22,
{ 14: } 24,
{ 15: } 26,
{ 16: } 28,
{ 17: } 30,
{ 18: } 32,
{ 19: } 34,
{ 20: } 36,
{ 21: } 38,
{ 22: } 40,
{ 23: } 42,
{ 24: } 44,
{ 25: } 46,
{ 26: } 48,
{ 27: } 50,
{ 28: } 52,
{ 29: } 54,
{ 30: } 56,
{ 31: } 58,
{ 32: } 60,
{ 33: } 62,
{ 34: } 64,
{ 35: } 66,
{ 36: } 68,
{ 37: } 70,
{ 38: } 72,
{ 39: } 74,
{ 40: } 76,
{ 41: } 78,
{ 42: } 80,
{ 43: } 82,
{ 44: } 84,
{ 45: } 86,
{ 46: } 88,
{ 47: } 90,
{ 48: } 92,
{ 49: } 94,
{ 50: } 95,
{ 51: } 97,
{ 52: } 98,
{ 53: } 99,
{ 54: } 100,
{ 55: } 101,
{ 56: } 102,
{ 57: } 102,
{ 58: } 103,
{ 59: } 104,
{ 60: } 105,
{ 61: } 106,
{ 62: } 107,
{ 63: } 108,
{ 64: } 109,
{ 65: } 110,
{ 66: } 111,
{ 67: } 112,
{ 68: } 113,
{ 69: } 114,
{ 70: } 115,
{ 71: } 116,
{ 72: } 117,
{ 73: } 118,
{ 74: } 119,
{ 75: } 120,
{ 76: } 121,
{ 77: } 122,
{ 78: } 123,
{ 79: } 124,
{ 80: } 125,
{ 81: } 126,
{ 82: } 127,
{ 83: } 128,
{ 84: } 129,
{ 85: } 130,
{ 86: } 131,
{ 87: } 132,
{ 88: } 133,
{ 89: } 135,
{ 90: } 136,
{ 91: } 137,
{ 92: } 138,
{ 93: } 139,
{ 94: } 140,
{ 95: } 141,
{ 96: } 142,
{ 97: } 143,
{ 98: } 144,
{ 99: } 145,
{ 100: } 146,
{ 101: } 147,
{ 102: } 148,
{ 103: } 149,
{ 104: } 149,
{ 105: } 150,
{ 106: } 150,
{ 107: } 151,
{ 108: } 152,
{ 109: } 153,
{ 110: } 154,
{ 111: } 155,
{ 112: } 155,
{ 113: } 155,
{ 114: } 155,
{ 115: } 155,
{ 116: } 156,
{ 117: } 156,
{ 118: } 156,
{ 119: } 156,
{ 120: } 157,
{ 121: } 157,
{ 122: } 158,
{ 123: } 159,
{ 124: } 160,
{ 125: } 161,
{ 126: } 162,
{ 127: } 163,
{ 128: } 164,
{ 129: } 165,
{ 130: } 166,
{ 131: } 167,
{ 132: } 168,
{ 133: } 169,
{ 134: } 170,
{ 135: } 171,
{ 136: } 172,
{ 137: } 173,
{ 138: } 174,
{ 139: } 175,
{ 140: } 176,
{ 141: } 177,
{ 142: } 178,
{ 143: } 179,
{ 144: } 180,
{ 145: } 181,
{ 146: } 182,
{ 147: } 183,
{ 148: } 184,
{ 149: } 185,
{ 150: } 186,
{ 151: } 187,
{ 152: } 189,
{ 153: } 190,
{ 154: } 191,
{ 155: } 192,
{ 156: } 194,
{ 157: } 195,
{ 158: } 196,
{ 159: } 197,
{ 160: } 198,
{ 161: } 199,
{ 162: } 200,
{ 163: } 201,
{ 164: } 202,
{ 165: } 203,
{ 166: } 204,
{ 167: } 204,
{ 168: } 205,
{ 169: } 205,
{ 170: } 206,
{ 171: } 206,
{ 172: } 207,
{ 173: } 208,
{ 174: } 208,
{ 175: } 208,
{ 176: } 208,
{ 177: } 208,
{ 178: } 208,
{ 179: } 208,
{ 180: } 208,
{ 181: } 209,
{ 182: } 210,
{ 183: } 212,
{ 184: } 214,
{ 185: } 215,
{ 186: } 216,
{ 187: } 217,
{ 188: } 218,
{ 189: } 219,
{ 190: } 220,
{ 191: } 221,
{ 192: } 222,
{ 193: } 223,
{ 194: } 224,
{ 195: } 225,
{ 196: } 226,
{ 197: } 227,
{ 198: } 228,
{ 199: } 229,
{ 200: } 230,
{ 201: } 231,
{ 202: } 233,
{ 203: } 234,
{ 204: } 235,
{ 205: } 236,
{ 206: } 238,
{ 207: } 239,
{ 208: } 241,
{ 209: } 243,
{ 210: } 244,
{ 211: } 245,
{ 212: } 246,
{ 213: } 247,
{ 214: } 248,
{ 215: } 249,
{ 216: } 250,
{ 217: } 251,
{ 218: } 252,
{ 219: } 253,
{ 220: } 254,
{ 221: } 255,
{ 222: } 256,
{ 223: } 257,
{ 224: } 258,
{ 225: } 259,
{ 226: } 259,
{ 227: } 260,
{ 228: } 260,
{ 229: } 260,
{ 230: } 260,
{ 231: } 261,
{ 232: } 261,
{ 233: } 261,
{ 234: } 261,
{ 235: } 261,
{ 236: } 261,
{ 237: } 261,
{ 238: } 261,
{ 239: } 263,
{ 240: } 264,
{ 241: } 265,
{ 242: } 266,
{ 243: } 267,
{ 244: } 269,
{ 245: } 271,
{ 246: } 272,
{ 247: } 273,
{ 248: } 274,
{ 249: } 276,
{ 250: } 277,
{ 251: } 278,
{ 252: } 279,
{ 253: } 280,
{ 254: } 282,
{ 255: } 283,
{ 256: } 284,
{ 257: } 285,
{ 258: } 286,
{ 259: } 287,
{ 260: } 289,
{ 261: } 291,
{ 262: } 292,
{ 263: } 293,
{ 264: } 295,
{ 265: } 297,
{ 266: } 298,
{ 267: } 299,
{ 268: } 300,
{ 269: } 301,
{ 270: } 302,
{ 271: } 303,
{ 272: } 304,
{ 273: } 305,
{ 274: } 306,
{ 275: } 307,
{ 276: } 308,
{ 277: } 308,
{ 278: } 308,
{ 279: } 308,
{ 280: } 308,
{ 281: } 308,
{ 282: } 308,
{ 283: } 308,
{ 284: } 308,
{ 285: } 309,
{ 286: } 311,
{ 287: } 312,
{ 288: } 313,
{ 289: } 314,
{ 290: } 316,
{ 291: } 317,
{ 292: } 318,
{ 293: } 319,
{ 294: } 321,
{ 295: } 323,
{ 296: } 325,
{ 297: } 326,
{ 298: } 327,
{ 299: } 328,
{ 300: } 329,
{ 301: } 330,
{ 302: } 331,
{ 303: } 333,
{ 304: } 334,
{ 305: } 335,
{ 306: } 337,
{ 307: } 338,
{ 308: } 340,
{ 309: } 341,
{ 310: } 343,
{ 311: } 344,
{ 312: } 346,
{ 313: } 348,
{ 314: } 348,
{ 315: } 348,
{ 316: } 348,
{ 317: } 348,
{ 318: } 348,
{ 319: } 350,
{ 320: } 352,
{ 321: } 353,
{ 322: } 355,
{ 323: } 357,
{ 324: } 359,
{ 325: } 361,
{ 326: } 362,
{ 327: } 363,
{ 328: } 364,
{ 329: } 365,
{ 330: } 366,
{ 331: } 367,
{ 332: } 368,
{ 333: } 369,
{ 334: } 371,
{ 335: } 372,
{ 336: } 373,
{ 337: } 373,
{ 338: } 375,
{ 339: } 376,
{ 340: } 377,
{ 341: } 379,
{ 342: } 381,
{ 343: } 382,
{ 344: } 384,
{ 345: } 385,
{ 346: } 386,
{ 347: } 388,
{ 348: } 389,
{ 349: } 390,
{ 350: } 392,
{ 351: } 394,
{ 352: } 395,
{ 353: } 397,
{ 354: } 399,
{ 355: } 401,
{ 356: } 403,
{ 357: } 405,
{ 358: } 406,
{ 359: } 408
);

yyml : array [0..yynstates-1] of Integer = (
{ 0: } 1,
{ 1: } 1,
{ 2: } 1,
{ 3: } 3,
{ 4: } 4,
{ 5: } 6,
{ 6: } 7,
{ 7: } 9,
{ 8: } 11,
{ 9: } 13,
{ 10: } 15,
{ 11: } 17,
{ 12: } 19,
{ 13: } 21,
{ 14: } 23,
{ 15: } 25,
{ 16: } 27,
{ 17: } 29,
{ 18: } 31,
{ 19: } 33,
{ 20: } 35,
{ 21: } 37,
{ 22: } 39,
{ 23: } 41,
{ 24: } 43,
{ 25: } 45,
{ 26: } 47,
{ 27: } 49,
{ 28: } 51,
{ 29: } 53,
{ 30: } 55,
{ 31: } 57,
{ 32: } 59,
{ 33: } 61,
{ 34: } 63,
{ 35: } 65,
{ 36: } 67,
{ 37: } 69,
{ 38: } 71,
{ 39: } 73,
{ 40: } 75,
{ 41: } 77,
{ 42: } 79,
{ 43: } 81,
{ 44: } 83,
{ 45: } 85,
{ 46: } 87,
{ 47: } 89,
{ 48: } 91,
{ 49: } 93,
{ 50: } 95,
{ 51: } 96,
{ 52: } 98,
{ 53: } 99,
{ 54: } 100,
{ 55: } 101,
{ 56: } 102,
{ 57: } 103,
{ 58: } 103,
{ 59: } 104,
{ 60: } 105,
{ 61: } 106,
{ 62: } 107,
{ 63: } 108,
{ 64: } 109,
{ 65: } 110,
{ 66: } 111,
{ 67: } 112,
{ 68: } 113,
{ 69: } 114,
{ 70: } 115,
{ 71: } 116,
{ 72: } 117,
{ 73: } 118,
{ 74: } 119,
{ 75: } 120,
{ 76: } 121,
{ 77: } 122,
{ 78: } 123,
{ 79: } 124,
{ 80: } 125,
{ 81: } 126,
{ 82: } 127,
{ 83: } 128,
{ 84: } 129,
{ 85: } 130,
{ 86: } 131,
{ 87: } 132,
{ 88: } 133,
{ 89: } 134,
{ 90: } 136,
{ 91: } 137,
{ 92: } 138,
{ 93: } 139,
{ 94: } 140,
{ 95: } 141,
{ 96: } 142,
{ 97: } 143,
{ 98: } 144,
{ 99: } 145,
{ 100: } 146,
{ 101: } 147,
{ 102: } 148,
{ 103: } 149,
{ 104: } 150,
{ 105: } 150,
{ 106: } 151,
{ 107: } 151,
{ 108: } 152,
{ 109: } 153,
{ 110: } 154,
{ 111: } 155,
{ 112: } 156,
{ 113: } 156,
{ 114: } 156,
{ 115: } 156,
{ 116: } 156,
{ 117: } 157,
{ 118: } 157,
{ 119: } 157,
{ 120: } 157,
{ 121: } 158,
{ 122: } 158,
{ 123: } 159,
{ 124: } 160,
{ 125: } 161,
{ 126: } 162,
{ 127: } 163,
{ 128: } 164,
{ 129: } 165,
{ 130: } 166,
{ 131: } 167,
{ 132: } 168,
{ 133: } 169,
{ 134: } 170,
{ 135: } 171,
{ 136: } 172,
{ 137: } 173,
{ 138: } 174,
{ 139: } 175,
{ 140: } 176,
{ 141: } 177,
{ 142: } 178,
{ 143: } 179,
{ 144: } 180,
{ 145: } 181,
{ 146: } 182,
{ 147: } 183,
{ 148: } 184,
{ 149: } 185,
{ 150: } 186,
{ 151: } 187,
{ 152: } 188,
{ 153: } 190,
{ 154: } 191,
{ 155: } 192,
{ 156: } 193,
{ 157: } 195,
{ 158: } 196,
{ 159: } 197,
{ 160: } 198,
{ 161: } 199,
{ 162: } 200,
{ 163: } 201,
{ 164: } 202,
{ 165: } 203,
{ 166: } 204,
{ 167: } 205,
{ 168: } 205,
{ 169: } 206,
{ 170: } 206,
{ 171: } 207,
{ 172: } 207,
{ 173: } 208,
{ 174: } 209,
{ 175: } 209,
{ 176: } 209,
{ 177: } 209,
{ 178: } 209,
{ 179: } 209,
{ 180: } 209,
{ 181: } 209,
{ 182: } 210,
{ 183: } 211,
{ 184: } 213,
{ 185: } 215,
{ 186: } 216,
{ 187: } 217,
{ 188: } 218,
{ 189: } 219,
{ 190: } 220,
{ 191: } 221,
{ 192: } 222,
{ 193: } 223,
{ 194: } 224,
{ 195: } 225,
{ 196: } 226,
{ 197: } 227,
{ 198: } 228,
{ 199: } 229,
{ 200: } 230,
{ 201: } 231,
{ 202: } 232,
{ 203: } 234,
{ 204: } 235,
{ 205: } 236,
{ 206: } 237,
{ 207: } 239,
{ 208: } 240,
{ 209: } 242,
{ 210: } 244,
{ 211: } 245,
{ 212: } 246,
{ 213: } 247,
{ 214: } 248,
{ 215: } 249,
{ 216: } 250,
{ 217: } 251,
{ 218: } 252,
{ 219: } 253,
{ 220: } 254,
{ 221: } 255,
{ 222: } 256,
{ 223: } 257,
{ 224: } 258,
{ 225: } 259,
{ 226: } 260,
{ 227: } 260,
{ 228: } 261,
{ 229: } 261,
{ 230: } 261,
{ 231: } 261,
{ 232: } 262,
{ 233: } 262,
{ 234: } 262,
{ 235: } 262,
{ 236: } 262,
{ 237: } 262,
{ 238: } 262,
{ 239: } 262,
{ 240: } 264,
{ 241: } 265,
{ 242: } 266,
{ 243: } 267,
{ 244: } 268,
{ 245: } 270,
{ 246: } 272,
{ 247: } 273,
{ 248: } 274,
{ 249: } 275,
{ 250: } 277,
{ 251: } 278,
{ 252: } 279,
{ 253: } 280,
{ 254: } 281,
{ 255: } 283,
{ 256: } 284,
{ 257: } 285,
{ 258: } 286,
{ 259: } 287,
{ 260: } 288,
{ 261: } 290,
{ 262: } 292,
{ 263: } 293,
{ 264: } 294,
{ 265: } 296,
{ 266: } 298,
{ 267: } 299,
{ 268: } 300,
{ 269: } 301,
{ 270: } 302,
{ 271: } 303,
{ 272: } 304,
{ 273: } 305,
{ 274: } 306,
{ 275: } 307,
{ 276: } 308,
{ 277: } 309,
{ 278: } 309,
{ 279: } 309,
{ 280: } 309,
{ 281: } 309,
{ 282: } 309,
{ 283: } 309,
{ 284: } 309,
{ 285: } 309,
{ 286: } 310,
{ 287: } 312,
{ 288: } 313,
{ 289: } 314,
{ 290: } 315,
{ 291: } 317,
{ 292: } 318,
{ 293: } 319,
{ 294: } 320,
{ 295: } 322,
{ 296: } 324,
{ 297: } 326,
{ 298: } 327,
{ 299: } 328,
{ 300: } 329,
{ 301: } 330,
{ 302: } 331,
{ 303: } 332,
{ 304: } 334,
{ 305: } 335,
{ 306: } 336,
{ 307: } 338,
{ 308: } 339,
{ 309: } 341,
{ 310: } 342,
{ 311: } 344,
{ 312: } 345,
{ 313: } 347,
{ 314: } 349,
{ 315: } 349,
{ 316: } 349,
{ 317: } 349,
{ 318: } 349,
{ 319: } 349,
{ 320: } 351,
{ 321: } 353,
{ 322: } 354,
{ 323: } 356,
{ 324: } 358,
{ 325: } 360,
{ 326: } 362,
{ 327: } 363,
{ 328: } 364,
{ 329: } 365,
{ 330: } 366,
{ 331: } 367,
{ 332: } 368,
{ 333: } 369,
{ 334: } 370,
{ 335: } 372,
{ 336: } 373,
{ 337: } 374,
{ 338: } 374,
{ 339: } 376,
{ 340: } 377,
{ 341: } 378,
{ 342: } 380,
{ 343: } 382,
{ 344: } 383,
{ 345: } 385,
{ 346: } 386,
{ 347: } 387,
{ 348: } 389,
{ 349: } 390,
{ 350: } 391,
{ 351: } 393,
{ 352: } 395,
{ 353: } 396,
{ 354: } 398,
{ 355: } 400,
{ 356: } 402,
{ 357: } 404,
{ 358: } 406,
{ 359: } 407
);

yymh : array [0..yynstates-1] of Integer = (
{ 0: } 0,
{ 1: } 0,
{ 2: } 2,
{ 3: } 3,
{ 4: } 5,
{ 5: } 6,
{ 6: } 8,
{ 7: } 10,
{ 8: } 12,
{ 9: } 14,
{ 10: } 16,
{ 11: } 18,
{ 12: } 20,
{ 13: } 22,
{ 14: } 24,
{ 15: } 26,
{ 16: } 28,
{ 17: } 30,
{ 18: } 32,
{ 19: } 34,
{ 20: } 36,
{ 21: } 38,
{ 22: } 40,
{ 23: } 42,
{ 24: } 44,
{ 25: } 46,
{ 26: } 48,
{ 27: } 50,
{ 28: } 52,
{ 29: } 54,
{ 30: } 56,
{ 31: } 58,
{ 32: } 60,
{ 33: } 62,
{ 34: } 64,
{ 35: } 66,
{ 36: } 68,
{ 37: } 70,
{ 38: } 72,
{ 39: } 74,
{ 40: } 76,
{ 41: } 78,
{ 42: } 80,
{ 43: } 82,
{ 44: } 84,
{ 45: } 86,
{ 46: } 88,
{ 47: } 90,
{ 48: } 92,
{ 49: } 94,
{ 50: } 95,
{ 51: } 97,
{ 52: } 98,
{ 53: } 99,
{ 54: } 100,
{ 55: } 101,
{ 56: } 102,
{ 57: } 102,
{ 58: } 103,
{ 59: } 104,
{ 60: } 105,
{ 61: } 106,
{ 62: } 107,
{ 63: } 108,
{ 64: } 109,
{ 65: } 110,
{ 66: } 111,
{ 67: } 112,
{ 68: } 113,
{ 69: } 114,
{ 70: } 115,
{ 71: } 116,
{ 72: } 117,
{ 73: } 118,
{ 74: } 119,
{ 75: } 120,
{ 76: } 121,
{ 77: } 122,
{ 78: } 123,
{ 79: } 124,
{ 80: } 125,
{ 81: } 126,
{ 82: } 127,
{ 83: } 128,
{ 84: } 129,
{ 85: } 130,
{ 86: } 131,
{ 87: } 132,
{ 88: } 133,
{ 89: } 135,
{ 90: } 136,
{ 91: } 137,
{ 92: } 138,
{ 93: } 139,
{ 94: } 140,
{ 95: } 141,
{ 96: } 142,
{ 97: } 143,
{ 98: } 144,
{ 99: } 145,
{ 100: } 146,
{ 101: } 147,
{ 102: } 148,
{ 103: } 149,
{ 104: } 149,
{ 105: } 150,
{ 106: } 150,
{ 107: } 151,
{ 108: } 152,
{ 109: } 153,
{ 110: } 154,
{ 111: } 155,
{ 112: } 155,
{ 113: } 155,
{ 114: } 155,
{ 115: } 155,
{ 116: } 156,
{ 117: } 156,
{ 118: } 156,
{ 119: } 156,
{ 120: } 157,
{ 121: } 157,
{ 122: } 158,
{ 123: } 159,
{ 124: } 160,
{ 125: } 161,
{ 126: } 162,
{ 127: } 163,
{ 128: } 164,
{ 129: } 165,
{ 130: } 166,
{ 131: } 167,
{ 132: } 168,
{ 133: } 169,
{ 134: } 170,
{ 135: } 171,
{ 136: } 172,
{ 137: } 173,
{ 138: } 174,
{ 139: } 175,
{ 140: } 176,
{ 141: } 177,
{ 142: } 178,
{ 143: } 179,
{ 144: } 180,
{ 145: } 181,
{ 146: } 182,
{ 147: } 183,
{ 148: } 184,
{ 149: } 185,
{ 150: } 186,
{ 151: } 187,
{ 152: } 189,
{ 153: } 190,
{ 154: } 191,
{ 155: } 192,
{ 156: } 194,
{ 157: } 195,
{ 158: } 196,
{ 159: } 197,
{ 160: } 198,
{ 161: } 199,
{ 162: } 200,
{ 163: } 201,
{ 164: } 202,
{ 165: } 203,
{ 166: } 204,
{ 167: } 204,
{ 168: } 205,
{ 169: } 205,
{ 170: } 206,
{ 171: } 206,
{ 172: } 207,
{ 173: } 208,
{ 174: } 208,
{ 175: } 208,
{ 176: } 208,
{ 177: } 208,
{ 178: } 208,
{ 179: } 208,
{ 180: } 208,
{ 181: } 209,
{ 182: } 210,
{ 183: } 212,
{ 184: } 214,
{ 185: } 215,
{ 186: } 216,
{ 187: } 217,
{ 188: } 218,
{ 189: } 219,
{ 190: } 220,
{ 191: } 221,
{ 192: } 222,
{ 193: } 223,
{ 194: } 224,
{ 195: } 225,
{ 196: } 226,
{ 197: } 227,
{ 198: } 228,
{ 199: } 229,
{ 200: } 230,
{ 201: } 231,
{ 202: } 233,
{ 203: } 234,
{ 204: } 235,
{ 205: } 236,
{ 206: } 238,
{ 207: } 239,
{ 208: } 241,
{ 209: } 243,
{ 210: } 244,
{ 211: } 245,
{ 212: } 246,
{ 213: } 247,
{ 214: } 248,
{ 215: } 249,
{ 216: } 250,
{ 217: } 251,
{ 218: } 252,
{ 219: } 253,
{ 220: } 254,
{ 221: } 255,
{ 222: } 256,
{ 223: } 257,
{ 224: } 258,
{ 225: } 259,
{ 226: } 259,
{ 227: } 260,
{ 228: } 260,
{ 229: } 260,
{ 230: } 260,
{ 231: } 261,
{ 232: } 261,
{ 233: } 261,
{ 234: } 261,
{ 235: } 261,
{ 236: } 261,
{ 237: } 261,
{ 238: } 261,
{ 239: } 263,
{ 240: } 264,
{ 241: } 265,
{ 242: } 266,
{ 243: } 267,
{ 244: } 269,
{ 245: } 271,
{ 246: } 272,
{ 247: } 273,
{ 248: } 274,
{ 249: } 276,
{ 250: } 277,
{ 251: } 278,
{ 252: } 279,
{ 253: } 280,
{ 254: } 282,
{ 255: } 283,
{ 256: } 284,
{ 257: } 285,
{ 258: } 286,
{ 259: } 287,
{ 260: } 289,
{ 261: } 291,
{ 262: } 292,
{ 263: } 293,
{ 264: } 295,
{ 265: } 297,
{ 266: } 298,
{ 267: } 299,
{ 268: } 300,
{ 269: } 301,
{ 270: } 302,
{ 271: } 303,
{ 272: } 304,
{ 273: } 305,
{ 274: } 306,
{ 275: } 307,
{ 276: } 308,
{ 277: } 308,
{ 278: } 308,
{ 279: } 308,
{ 280: } 308,
{ 281: } 308,
{ 282: } 308,
{ 283: } 308,
{ 284: } 308,
{ 285: } 309,
{ 286: } 311,
{ 287: } 312,
{ 288: } 313,
{ 289: } 314,
{ 290: } 316,
{ 291: } 317,
{ 292: } 318,
{ 293: } 319,
{ 294: } 321,
{ 295: } 323,
{ 296: } 325,
{ 297: } 326,
{ 298: } 327,
{ 299: } 328,
{ 300: } 329,
{ 301: } 330,
{ 302: } 331,
{ 303: } 333,
{ 304: } 334,
{ 305: } 335,
{ 306: } 337,
{ 307: } 338,
{ 308: } 340,
{ 309: } 341,
{ 310: } 343,
{ 311: } 344,
{ 312: } 346,
{ 313: } 348,
{ 314: } 348,
{ 315: } 348,
{ 316: } 348,
{ 317: } 348,
{ 318: } 348,
{ 319: } 350,
{ 320: } 352,
{ 321: } 353,
{ 322: } 355,
{ 323: } 357,
{ 324: } 359,
{ 325: } 361,
{ 326: } 362,
{ 327: } 363,
{ 328: } 364,
{ 329: } 365,
{ 330: } 366,
{ 331: } 367,
{ 332: } 368,
{ 333: } 369,
{ 334: } 371,
{ 335: } 372,
{ 336: } 373,
{ 337: } 373,
{ 338: } 375,
{ 339: } 376,
{ 340: } 377,
{ 341: } 379,
{ 342: } 381,
{ 343: } 382,
{ 344: } 384,
{ 345: } 385,
{ 346: } 386,
{ 347: } 388,
{ 348: } 389,
{ 349: } 390,
{ 350: } 392,
{ 351: } 394,
{ 352: } 395,
{ 353: } 397,
{ 354: } 399,
{ 355: } 401,
{ 356: } 403,
{ 357: } 405,
{ 358: } 406,
{ 359: } 408
);

yytl : array [0..yynstates-1] of Integer = (
{ 0: } 1,
{ 1: } 54,
{ 2: } 107,
{ 3: } 107,
{ 4: } 107,
{ 5: } 108,
{ 6: } 109,
{ 7: } 109,
{ 8: } 109,
{ 9: } 109,
{ 10: } 109,
{ 11: } 109,
{ 12: } 109,
{ 13: } 110,
{ 14: } 110,
{ 15: } 110,
{ 16: } 110,
{ 17: } 111,
{ 18: } 112,
{ 19: } 112,
{ 20: } 112,
{ 21: } 112,
{ 22: } 112,
{ 23: } 112,
{ 24: } 112,
{ 25: } 112,
{ 26: } 112,
{ 27: } 117,
{ 28: } 120,
{ 29: } 124,
{ 30: } 127,
{ 31: } 130,
{ 32: } 132,
{ 33: } 138,
{ 34: } 141,
{ 35: } 143,
{ 36: } 145,
{ 37: } 147,
{ 38: } 149,
{ 39: } 152,
{ 40: } 154,
{ 41: } 158,
{ 42: } 162,
{ 43: } 165,
{ 44: } 167,
{ 45: } 169,
{ 46: } 171,
{ 47: } 174,
{ 48: } 176,
{ 49: } 177,
{ 50: } 183,
{ 51: } 184,
{ 52: } 188,
{ 53: } 190,
{ 54: } 193,
{ 55: } 193,
{ 56: } 197,
{ 57: } 198,
{ 58: } 199,
{ 59: } 199,
{ 60: } 199,
{ 61: } 199,
{ 62: } 201,
{ 63: } 203,
{ 64: } 205,
{ 65: } 207,
{ 66: } 208,
{ 67: } 210,
{ 68: } 212,
{ 69: } 214,
{ 70: } 216,
{ 71: } 218,
{ 72: } 220,
{ 73: } 222,
{ 74: } 224,
{ 75: } 226,
{ 76: } 228,
{ 77: } 230,
{ 78: } 232,
{ 79: } 234,
{ 80: } 236,
{ 81: } 238,
{ 82: } 240,
{ 83: } 242,
{ 84: } 245,
{ 85: } 247,
{ 86: } 249,
{ 87: } 251,
{ 88: } 253,
{ 89: } 255,
{ 90: } 258,
{ 91: } 260,
{ 92: } 262,
{ 93: } 264,
{ 94: } 266,
{ 95: } 268,
{ 96: } 270,
{ 97: } 272,
{ 98: } 274,
{ 99: } 276,
{ 100: } 278,
{ 101: } 280,
{ 102: } 282,
{ 103: } 284,
{ 104: } 286,
{ 105: } 290,
{ 106: } 293,
{ 107: } 295,
{ 108: } 295,
{ 109: } 300,
{ 110: } 301,
{ 111: } 304,
{ 112: } 308,
{ 113: } 309,
{ 114: } 312,
{ 115: } 315,
{ 116: } 318,
{ 117: } 318,
{ 118: } 321,
{ 119: } 324,
{ 120: } 326,
{ 121: } 326,
{ 122: } 327,
{ 123: } 330,
{ 124: } 332,
{ 125: } 334,
{ 126: } 336,
{ 127: } 338,
{ 128: } 340,
{ 129: } 342,
{ 130: } 344,
{ 131: } 346,
{ 132: } 348,
{ 133: } 350,
{ 134: } 352,
{ 135: } 354,
{ 136: } 356,
{ 137: } 359,
{ 138: } 361,
{ 139: } 363,
{ 140: } 365,
{ 141: } 367,
{ 142: } 369,
{ 143: } 371,
{ 144: } 373,
{ 145: } 375,
{ 146: } 377,
{ 147: } 379,
{ 148: } 381,
{ 149: } 383,
{ 150: } 385,
{ 151: } 387,
{ 152: } 389,
{ 153: } 390,
{ 154: } 392,
{ 155: } 394,
{ 156: } 396,
{ 157: } 397,
{ 158: } 399,
{ 159: } 401,
{ 160: } 403,
{ 161: } 405,
{ 162: } 407,
{ 163: } 409,
{ 164: } 411,
{ 165: } 413,
{ 166: } 415,
{ 167: } 418,
{ 168: } 420,
{ 169: } 420,
{ 170: } 422,
{ 171: } 423,
{ 172: } 425,
{ 173: } 425,
{ 174: } 425,
{ 175: } 427,
{ 176: } 428,
{ 177: } 432,
{ 178: } 433,
{ 179: } 436,
{ 180: } 439,
{ 181: } 440,
{ 182: } 442,
{ 183: } 444,
{ 184: } 445,
{ 185: } 446,
{ 186: } 448,
{ 187: } 450,
{ 188: } 452,
{ 189: } 454,
{ 190: } 456,
{ 191: } 458,
{ 192: } 460,
{ 193: } 462,
{ 194: } 464,
{ 195: } 466,
{ 196: } 468,
{ 197: } 470,
{ 198: } 472,
{ 199: } 474,
{ 200: } 476,
{ 201: } 478,
{ 202: } 480,
{ 203: } 481,
{ 204: } 483,
{ 205: } 485,
{ 206: } 487,
{ 207: } 488,
{ 208: } 490,
{ 209: } 491,
{ 210: } 492,
{ 211: } 494,
{ 212: } 496,
{ 213: } 498,
{ 214: } 500,
{ 215: } 502,
{ 216: } 504,
{ 217: } 506,
{ 218: } 508,
{ 219: } 510,
{ 220: } 512,
{ 221: } 514,
{ 222: } 516,
{ 223: } 518,
{ 224: } 520,
{ 225: } 522,
{ 226: } 522,
{ 227: } 524,
{ 228: } 525,
{ 229: } 527,
{ 230: } 528,
{ 231: } 530,
{ 232: } 531,
{ 233: } 533,
{ 234: } 535,
{ 235: } 538,
{ 236: } 541,
{ 237: } 544,
{ 238: } 547,
{ 239: } 548,
{ 240: } 549,
{ 241: } 551,
{ 242: } 553,
{ 243: } 555,
{ 244: } 557,
{ 245: } 558,
{ 246: } 559,
{ 247: } 561,
{ 248: } 563,
{ 249: } 565,
{ 250: } 566,
{ 251: } 568,
{ 252: } 570,
{ 253: } 572,
{ 254: } 574,
{ 255: } 575,
{ 256: } 577,
{ 257: } 579,
{ 258: } 581,
{ 259: } 583,
{ 260: } 585,
{ 261: } 586,
{ 262: } 587,
{ 263: } 589,
{ 264: } 591,
{ 265: } 592,
{ 266: } 593,
{ 267: } 595,
{ 268: } 597,
{ 269: } 599,
{ 270: } 601,
{ 271: } 603,
{ 272: } 605,
{ 273: } 607,
{ 274: } 609,
{ 275: } 611,
{ 276: } 613,
{ 277: } 615,
{ 278: } 617,
{ 279: } 618,
{ 280: } 619,
{ 281: } 621,
{ 282: } 622,
{ 283: } 625,
{ 284: } 628,
{ 285: } 629,
{ 286: } 631,
{ 287: } 632,
{ 288: } 634,
{ 289: } 636,
{ 290: } 638,
{ 291: } 639,
{ 292: } 641,
{ 293: } 643,
{ 294: } 645,
{ 295: } 646,
{ 296: } 647,
{ 297: } 648,
{ 298: } 650,
{ 299: } 652,
{ 300: } 654,
{ 301: } 656,
{ 302: } 658,
{ 303: } 660,
{ 304: } 661,
{ 305: } 663,
{ 306: } 665,
{ 307: } 666,
{ 308: } 668,
{ 309: } 669,
{ 310: } 671,
{ 311: } 672,
{ 312: } 674,
{ 313: } 675,
{ 314: } 676,
{ 315: } 677,
{ 316: } 678,
{ 317: } 681,
{ 318: } 683,
{ 319: } 685,
{ 320: } 686,
{ 321: } 687,
{ 322: } 689,
{ 323: } 690,
{ 324: } 691,
{ 325: } 692,
{ 326: } 693,
{ 327: } 695,
{ 328: } 697,
{ 329: } 699,
{ 330: } 701,
{ 331: } 703,
{ 332: } 705,
{ 333: } 707,
{ 334: } 709,
{ 335: } 710,
{ 336: } 712,
{ 337: } 714,
{ 338: } 716,
{ 339: } 716,
{ 340: } 716,
{ 341: } 718,
{ 342: } 719,
{ 343: } 720,
{ 344: } 722,
{ 345: } 723,
{ 346: } 725,
{ 347: } 727,
{ 348: } 728,
{ 349: } 730,
{ 350: } 732,
{ 351: } 733,
{ 352: } 733,
{ 353: } 735,
{ 354: } 736,
{ 355: } 737,
{ 356: } 738,
{ 357: } 739,
{ 358: } 740,
{ 359: } 742
);

yyth : array [0..yynstates-1] of Integer = (
{ 0: } 53,
{ 1: } 106,
{ 2: } 106,
{ 3: } 106,
{ 4: } 107,
{ 5: } 108,
{ 6: } 108,
{ 7: } 108,
{ 8: } 108,
{ 9: } 108,
{ 10: } 108,
{ 11: } 108,
{ 12: } 109,
{ 13: } 109,
{ 14: } 109,
{ 15: } 109,
{ 16: } 110,
{ 17: } 111,
{ 18: } 111,
{ 19: } 111,
{ 20: } 111,
{ 21: } 111,
{ 22: } 111,
{ 23: } 111,
{ 24: } 111,
{ 25: } 111,
{ 26: } 116,
{ 27: } 119,
{ 28: } 123,
{ 29: } 126,
{ 30: } 129,
{ 31: } 131,
{ 32: } 137,
{ 33: } 140,
{ 34: } 142,
{ 35: } 144,
{ 36: } 146,
{ 37: } 148,
{ 38: } 151,
{ 39: } 153,
{ 40: } 157,
{ 41: } 161,
{ 42: } 164,
{ 43: } 166,
{ 44: } 168,
{ 45: } 170,
{ 46: } 173,
{ 47: } 175,
{ 48: } 176,
{ 49: } 182,
{ 50: } 183,
{ 51: } 187,
{ 52: } 189,
{ 53: } 192,
{ 54: } 192,
{ 55: } 196,
{ 56: } 197,
{ 57: } 198,
{ 58: } 198,
{ 59: } 198,
{ 60: } 198,
{ 61: } 200,
{ 62: } 202,
{ 63: } 204,
{ 64: } 206,
{ 65: } 207,
{ 66: } 209,
{ 67: } 211,
{ 68: } 213,
{ 69: } 215,
{ 70: } 217,
{ 71: } 219,
{ 72: } 221,
{ 73: } 223,
{ 74: } 225,
{ 75: } 227,
{ 76: } 229,
{ 77: } 231,
{ 78: } 233,
{ 79: } 235,
{ 80: } 237,
{ 81: } 239,
{ 82: } 241,
{ 83: } 244,
{ 84: } 246,
{ 85: } 248,
{ 86: } 250,
{ 87: } 252,
{ 88: } 254,
{ 89: } 257,
{ 90: } 259,
{ 91: } 261,
{ 92: } 263,
{ 93: } 265,
{ 94: } 267,
{ 95: } 269,
{ 96: } 271,
{ 97: } 273,
{ 98: } 275,
{ 99: } 277,
{ 100: } 279,
{ 101: } 281,
{ 102: } 283,
{ 103: } 285,
{ 104: } 289,
{ 105: } 292,
{ 106: } 294,
{ 107: } 294,
{ 108: } 299,
{ 109: } 300,
{ 110: } 303,
{ 111: } 307,
{ 112: } 308,
{ 113: } 311,
{ 114: } 314,
{ 115: } 317,
{ 116: } 317,
{ 117: } 320,
{ 118: } 323,
{ 119: } 325,
{ 120: } 325,
{ 121: } 326,
{ 122: } 329,
{ 123: } 331,
{ 124: } 333,
{ 125: } 335,
{ 126: } 337,
{ 127: } 339,
{ 128: } 341,
{ 129: } 343,
{ 130: } 345,
{ 131: } 347,
{ 132: } 349,
{ 133: } 351,
{ 134: } 353,
{ 135: } 355,
{ 136: } 358,
{ 137: } 360,
{ 138: } 362,
{ 139: } 364,
{ 140: } 366,
{ 141: } 368,
{ 142: } 370,
{ 143: } 372,
{ 144: } 374,
{ 145: } 376,
{ 146: } 378,
{ 147: } 380,
{ 148: } 382,
{ 149: } 384,
{ 150: } 386,
{ 151: } 388,
{ 152: } 389,
{ 153: } 391,
{ 154: } 393,
{ 155: } 395,
{ 156: } 396,
{ 157: } 398,
{ 158: } 400,
{ 159: } 402,
{ 160: } 404,
{ 161: } 406,
{ 162: } 408,
{ 163: } 410,
{ 164: } 412,
{ 165: } 414,
{ 166: } 417,
{ 167: } 419,
{ 168: } 419,
{ 169: } 421,
{ 170: } 422,
{ 171: } 424,
{ 172: } 424,
{ 173: } 424,
{ 174: } 426,
{ 175: } 427,
{ 176: } 431,
{ 177: } 432,
{ 178: } 435,
{ 179: } 438,
{ 180: } 439,
{ 181: } 441,
{ 182: } 443,
{ 183: } 444,
{ 184: } 445,
{ 185: } 447,
{ 186: } 449,
{ 187: } 451,
{ 188: } 453,
{ 189: } 455,
{ 190: } 457,
{ 191: } 459,
{ 192: } 461,
{ 193: } 463,
{ 194: } 465,
{ 195: } 467,
{ 196: } 469,
{ 197: } 471,
{ 198: } 473,
{ 199: } 475,
{ 200: } 477,
{ 201: } 479,
{ 202: } 480,
{ 203: } 482,
{ 204: } 484,
{ 205: } 486,
{ 206: } 487,
{ 207: } 489,
{ 208: } 490,
{ 209: } 491,
{ 210: } 493,
{ 211: } 495,
{ 212: } 497,
{ 213: } 499,
{ 214: } 501,
{ 215: } 503,
{ 216: } 505,
{ 217: } 507,
{ 218: } 509,
{ 219: } 511,
{ 220: } 513,
{ 221: } 515,
{ 222: } 517,
{ 223: } 519,
{ 224: } 521,
{ 225: } 521,
{ 226: } 523,
{ 227: } 524,
{ 228: } 526,
{ 229: } 527,
{ 230: } 529,
{ 231: } 530,
{ 232: } 532,
{ 233: } 534,
{ 234: } 537,
{ 235: } 540,
{ 236: } 543,
{ 237: } 546,
{ 238: } 547,
{ 239: } 548,
{ 240: } 550,
{ 241: } 552,
{ 242: } 554,
{ 243: } 556,
{ 244: } 557,
{ 245: } 558,
{ 246: } 560,
{ 247: } 562,
{ 248: } 564,
{ 249: } 565,
{ 250: } 567,
{ 251: } 569,
{ 252: } 571,
{ 253: } 573,
{ 254: } 574,
{ 255: } 576,
{ 256: } 578,
{ 257: } 580,
{ 258: } 582,
{ 259: } 584,
{ 260: } 585,
{ 261: } 586,
{ 262: } 588,
{ 263: } 590,
{ 264: } 591,
{ 265: } 592,
{ 266: } 594,
{ 267: } 596,
{ 268: } 598,
{ 269: } 600,
{ 270: } 602,
{ 271: } 604,
{ 272: } 606,
{ 273: } 608,
{ 274: } 610,
{ 275: } 612,
{ 276: } 614,
{ 277: } 616,
{ 278: } 617,
{ 279: } 618,
{ 280: } 620,
{ 281: } 621,
{ 282: } 624,
{ 283: } 627,
{ 284: } 628,
{ 285: } 630,
{ 286: } 631,
{ 287: } 633,
{ 288: } 635,
{ 289: } 637,
{ 290: } 638,
{ 291: } 640,
{ 292: } 642,
{ 293: } 644,
{ 294: } 645,
{ 295: } 646,
{ 296: } 647,
{ 297: } 649,
{ 298: } 651,
{ 299: } 653,
{ 300: } 655,
{ 301: } 657,
{ 302: } 659,
{ 303: } 660,
{ 304: } 662,
{ 305: } 664,
{ 306: } 665,
{ 307: } 667,
{ 308: } 668,
{ 309: } 670,
{ 310: } 671,
{ 311: } 673,
{ 312: } 674,
{ 313: } 675,
{ 314: } 676,
{ 315: } 677,
{ 316: } 680,
{ 317: } 682,
{ 318: } 684,
{ 319: } 685,
{ 320: } 686,
{ 321: } 688,
{ 322: } 689,
{ 323: } 690,
{ 324: } 691,
{ 325: } 692,
{ 326: } 694,
{ 327: } 696,
{ 328: } 698,
{ 329: } 700,
{ 330: } 702,
{ 331: } 704,
{ 332: } 706,
{ 333: } 708,
{ 334: } 709,
{ 335: } 711,
{ 336: } 713,
{ 337: } 715,
{ 338: } 715,
{ 339: } 715,
{ 340: } 717,
{ 341: } 718,
{ 342: } 719,
{ 343: } 721,
{ 344: } 722,
{ 345: } 724,
{ 346: } 726,
{ 347: } 727,
{ 348: } 729,
{ 349: } 731,
{ 350: } 732,
{ 351: } 732,
{ 352: } 734,
{ 353: } 735,
{ 354: } 736,
{ 355: } 737,
{ 356: } 738,
{ 357: } 739,
{ 358: } 741,
{ 359: } 742
);


var yyn : Integer;

label start, scan, action;

begin

start:

  (* initialize: *)

  yynew;

scan:

  (* mark positions and matches: *)

  for yyn := yykl[yystate] to     yykh[yystate] do yymark(yyk[yyn]);
  for yyn := yymh[yystate] downto yyml[yystate] do yymatch(yym[yyn]);

  if yytl[yystate]>yyth[yystate] then goto action; (* dead state *)

  (* get next character: *)

  yyscan;

  (* determine action: *)

  yyn := yytl[yystate];
  while (yyn<=yyth[yystate]) and not (yyactchar in yyt[yyn].cc) do inc(yyn);
  if yyn>yyth[yystate] then goto action;
    (* no transition on yyactchar in this state *)

  (* switch to new state: *)

  yystate := yyt[yyn].s;

  goto scan;

action:

  (* execute action: *)

  if yyfind(yyrule) then
    begin
      yyaction(yyrule);
      if yyreject then goto action;
    end
  else if not yydefault and yywrap then
    begin
      yyclear;
      return(0);
    end;

  if not yydone then goto start;

  yylex := yyretval;

end(*yylex*);


